@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * channel
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,14 +25,17 @@
  * -------------------------------------------------------------------------- */
 
 
+#include <cassert>
+#include <cstring>
 #include "../utils/log.h"
 #include "../gui/elems/mainWindow/keyboard/channel.h"
+#include "const.h"
 #include "channel.h"
 #include "pluginHost.h"
 #include "plugin.h"
 #include "kernelMidi.h"
-#include "patch_DEPR_.h"
 #include "patch.h"
+#include "clock.h"
 #include "wave.h"
 #include "mixer.h"
 #include "mixerHandler.h"
@@ -44,26 +45,20 @@
 #include "midiMapConf.h"
 
 
-extern Recorder   G_Recorder;
-extern KernelMidi G_KernelMidi;
+using std::string;
+using namespace giada::m;
 
 
-Channel::Channel(int type, int status, int bufferSize, MidiMapConf *midiMapConf)
-#if defined(WITH_VST)
-: pluginHost(nullptr),
-#else
-:
-#endif
-  midiMapConf    (midiMapConf),
-  bufferSize     (bufferSize),
+Channel::Channel(int type, int status, int bufferSize)
+: bufferSize     (bufferSize),
+  midiFilter     (-1),
+  pan            (0.5f),
   type           (type),
-	status         (status),
-	key            (0),
-  volume         (DEFAULT_VOL),
+  status         (status),
+  key            (0),
+  volume         (G_DEFAULT_VOL),
   volume_i       (1.0f),
   volume_d       (0.0f),
-  panLeft        (1.0f),
-  panRight       (1.0f),
   mute_i         (false),
   mute_s         (false),
   mute           (false),
@@ -90,7 +85,7 @@ Channel::Channel(int type, int status, int bufferSize, MidiMapConf *midiMapConf)
   vChan = (float *) malloc(bufferSize * sizeof(float));
 	if (!vChan)
 		gu_log("[Channel::allocVchan] unable to alloc memory for vChan\n");
-	memset(vChan, 0, bufferSize * sizeof(float));
+	std::memset(vChan, 0, bufferSize * sizeof(float));
 }
 
 
@@ -114,8 +109,7 @@ void Channel::copy(const Channel *src, pthread_mutex_t *pluginMutex)
   volume          = src->volume;
   volume_i        = src->volume_i;
   volume_d        = src->volume_d;
-  panLeft         = src->panLeft;
-  panRight        = src->panRight;
+  pan             = src->pan;
   mute_i          = src->mute_i;
   mute_s          = src->mute_s;
   mute            = src->mute;
@@ -139,17 +133,17 @@ void Channel::copy(const Channel *src, pthread_mutex_t *pluginMutex)
 
 #ifdef WITH_VST
   for (unsigned i=0; i<src->plugins.size(); i++)
-    pluginHost->clonePlugin(src->plugins.at(i), PluginHost::CHANNEL,
+    pluginHost::clonePlugin(src->plugins.at(i), pluginHost::CHANNEL,
       pluginMutex, this);
 #endif
 
   /* clone actions */
 
-  for (unsigned i=0; i<G_Recorder.global.size(); i++) {
-    for (unsigned k=0; k<G_Recorder.global.at(i).size(); k++) {
-      Recorder::action *a = G_Recorder.global.at(i).at(k);
+  for (unsigned i=0; i<recorder::global.size(); i++) {
+    for (unsigned k=0; k<recorder::global.at(i).size(); k++) {
+      recorder::action *a = recorder::global.at(i).at(k);
       if (a->chan == src->index) {
-        G_Recorder.rec(index, a->type, a->frame, a->iValue, a->fValue);
+        recorder::rec(index, a->type, a->frame, a->iValue, a->fValue);
         hasActions = true;
       }
     }
@@ -160,7 +154,7 @@ void Channel::copy(const Channel *src, pthread_mutex_t *pluginMutex)
 /* -------------------------------------------------------------------------- */
 
 
-void Channel::sendMidiLmessage(uint32_t learn, const MidiMapConf::message_t &msg)
+void Channel::sendMidiLmessage(uint32_t learn, const midimap::message_t &msg)
 {
 	gu_log("[channel::sendMidiLmessage] learn=%#X, chan=%d, msg=%#X, offset=%d\n",
 		learn, msg.channel, msg.value, msg.offset);
@@ -174,30 +168,7 @@ void Channel::sendMidiLmessage(uint32_t learn, const MidiMapConf::message_t &msg
 	 * send it. */
 
 	out |= msg.value | (msg.channel << 24);
-	G_KernelMidi.send(out);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void Channel::readPatchMidiIn_DEPR_(int i, Patch_DEPR_ &patch)
-{
-	midiIn         = patch.getMidiValue(i, "In");
-	midiInKeyPress = patch.getMidiValue(i, "InKeyPress");
-	midiInKeyRel   = patch.getMidiValue(i, "InKeyRel");
-  midiInKill     = patch.getMidiValue(i, "InKill");
-  midiInVolume   = patch.getMidiValue(i, "InVolume");
-  midiInMute     = patch.getMidiValue(i, "InMute");
-  midiInSolo     = patch.getMidiValue(i, "InSolo");
-}
-
-void Channel::readPatchMidiOut_DEPR_(int i, Patch_DEPR_ &patch)
-{
-	midiOutL        = patch.getMidiValue(i, "OutL");
-	midiOutLplaying = patch.getMidiValue(i, "OutLplaying");
-	midiOutLmute    = patch.getMidiValue(i, "OutLmute");
-	midiOutLsolo    = patch.getMidiValue(i, "OutLsolo");
+	kernelMidi::send(out);
 }
 
 
@@ -213,9 +184,9 @@ bool Channel::isPlaying()
 /* -------------------------------------------------------------------------- */
 
 
-int Channel::writePatch(int i, bool isProject, Patch *patch)
+int Channel::writePatch(int i, bool isProject)
 {
-	Patch::channel_t pch;
+	patch::channel_t pch;
 	pch.type            = type;
 	pch.key             = key;
 	pch.index           = index;
@@ -224,8 +195,7 @@ int Channel::writePatch(int i, bool isProject, Patch *patch)
 	pch.mute_s          = mute_s;
 	pch.solo            = solo;
 	pch.volume          = volume;
-	pch.panLeft         = panLeft;
-	pch.panRight        = panRight;
+	pch.pan             = pan;
 	pch.midiIn          = midiIn;
 	pch.midiInKeyPress  = midiInKeyPress;
 	pch.midiInKeyRel    = midiInKeyRel;
@@ -239,11 +209,11 @@ int Channel::writePatch(int i, bool isProject, Patch *patch)
 	pch.midiOutLmute    = midiOutLmute;
 	pch.midiOutLsolo    = midiOutLsolo;
 
-	for (unsigned i=0; i<G_Recorder.global.size(); i++) {
-		for (unsigned k=0; k<G_Recorder.global.at(i).size(); k++) {
-			Recorder::action *action = G_Recorder.global.at(i).at(k);
+	for (unsigned i=0; i<recorder::global.size(); i++) {
+		for (unsigned k=0; k<recorder::global.at(i).size(); k++) {
+			recorder::action *action = recorder::global.at(i).at(k);
 			if (action->chan == index) {
-				Patch::action_t pac;
+				patch::action_t pac;
 				pac.type   = action->type;
 		    pac.frame  = action->frame;
 		    pac.fValue = action->fValue;
@@ -255,10 +225,10 @@ int Channel::writePatch(int i, bool isProject, Patch *patch)
 
 #ifdef WITH_VST
 
-	unsigned numPlugs = pluginHost->countPlugins(PluginHost::CHANNEL, this);
+	unsigned numPlugs = pluginHost::countPlugins(pluginHost::CHANNEL, this);
 	for (unsigned i=0; i<numPlugs; i++) {
-		Plugin *pPlugin = pluginHost->getPluginByIndex(i, PluginHost::CHANNEL, this);
-		Patch::plugin_t pp;
+		Plugin *pPlugin = pluginHost::getPluginByIndex(i, pluginHost::CHANNEL, this);
+		patch::plugin_t pp;
 		pp.path   = pPlugin->getUniqueId();
     pp.bypass = pPlugin->isBypassed();
 		for (int k=0; k<pPlugin->getNumParameters(); k++)
@@ -270,20 +240,20 @@ int Channel::writePatch(int i, bool isProject, Patch *patch)
 
 #endif
 
-	patch->channels.push_back(pch);
+	patch::channels.push_back(pch);
 
-	return patch->channels.size() - 1;
+	return patch::channels.size() - 1;
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-int Channel::readPatch(const string &path, int i, Patch *patch,
-    pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality)
+int Channel::readPatch(const string &path, int i, pthread_mutex_t *pluginMutex,
+  int samplerate, int rsmpQuality)
 {
 	int ret = 1;
-	Patch::channel_t *pch = &patch->channels.at(i);
+	patch::channel_t *pch = &patch::channels.at(i);
 	key             = pch->key;
 	type            = pch->type;
 	index           = pch->index;
@@ -291,8 +261,7 @@ int Channel::readPatch(const string &path, int i, Patch *patch,
 	mute_s          = pch->mute_s;
 	solo            = pch->solo;
 	volume          = pch->volume;
-	panLeft         = pch->panLeft;
-	panRight        = pch->panRight;
+	pan             = pch->pan;
 	midiIn          = pch->midiIn;
 	midiInKeyPress  = pch->midiInKeyPress;
 	midiInKeyRel    = pch->midiInKeyRel;
@@ -306,16 +275,16 @@ int Channel::readPatch(const string &path, int i, Patch *patch,
 	midiOutLsolo    = pch->midiOutLsolo;
 
 	for (unsigned k=0; k<pch->actions.size(); k++) {
-		Patch::action_t *ac = &pch->actions.at(k);
-		G_Recorder.rec(index, ac->type, ac->frame, ac->iValue, ac->fValue);
+		patch::action_t *ac = &pch->actions.at(k);
+		recorder::rec(index, ac->type, ac->frame, ac->iValue, ac->fValue);
     hasActions = true;
 	}
 
 #ifdef WITH_VST
 
 	for (unsigned k=0; k<pch->plugins.size(); k++) {
-		Patch::plugin_t *ppl = &pch->plugins.at(k);
-		Plugin *plugin = pluginHost->addPlugin(ppl->path, PluginHost::CHANNEL,
+		patch::plugin_t *ppl = &pch->plugins.at(k);
+		Plugin *plugin = pluginHost::addPlugin(ppl->path, pluginHost::CHANNEL,
       pluginMutex, this);
     if (plugin == nullptr) {
       ret &= 0;
@@ -344,9 +313,9 @@ void Channel::sendMidiLmute()
 	if (!midiOutL || midiOutLmute == 0x0)
 		return;
 	if (mute)
-		sendMidiLmessage(midiOutLsolo, midiMapConf->muteOn);
+		sendMidiLmessage(midiOutLsolo, midimap::muteOn);
 	else
-		sendMidiLmessage(midiOutLsolo, midiMapConf->muteOff);
+		sendMidiLmessage(midiOutLsolo, midimap::muteOff);
 }
 
 
@@ -358,9 +327,9 @@ void Channel::sendMidiLsolo()
 	if (!midiOutL || midiOutLsolo == 0x0)
 		return;
 	if (solo)
-		sendMidiLmessage(midiOutLsolo, midiMapConf->soloOn);
+		sendMidiLmessage(midiOutLsolo, midimap::soloOn);
 	else
-		sendMidiLmessage(midiOutLsolo, midiMapConf->soloOff);
+		sendMidiLmessage(midiOutLsolo, midimap::soloOff);
 }
 
 
@@ -373,16 +342,16 @@ void Channel::sendMidiLplay()
 		return;
 	switch (status) {
 		case STATUS_OFF:
-			sendMidiLmessage(midiOutLplaying, midiMapConf->stopped);
+			sendMidiLmessage(midiOutLplaying, midimap::stopped);
 			break;
 		case STATUS_PLAY:
-			sendMidiLmessage(midiOutLplaying, midiMapConf->playing);
+			sendMidiLmessage(midiOutLplaying, midimap::playing);
 			break;
 		case STATUS_WAIT:
-			sendMidiLmessage(midiOutLplaying, midiMapConf->waiting);
+			sendMidiLmessage(midiOutLplaying, midimap::waiting);
 			break;
 		case STATUS_ENDING:
-			sendMidiLmessage(midiOutLplaying, midiMapConf->stopping);
+			sendMidiLmessage(midiOutLplaying, midimap::stopping);
 	}
 }
 
@@ -397,6 +366,41 @@ void Channel::receiveMidi(uint32_t msg)
 /* -------------------------------------------------------------------------- */
 
 
+void Channel::setPan(float v)
+{
+  if (v > 1.0f)
+    pan = 1.0f;
+  else 
+  if (v < 0.0f)
+    pan = 0.0f;
+  else
+    pan = v;
+}
+
+
+float Channel::getPan()
+{
+  return pan;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+float Channel::calcPanning(int ch)
+{
+  if (pan == 0.5f) // center: nothing to do
+    return 1.0;
+  if (ch == 0)
+    return 1.0 - pan;
+  else  // channel 1
+    return pan; 
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 #ifdef WITH_VST
 
 juce::MidiBuffer &Channel::getPluginMidiEvents()
@@ -414,12 +418,4 @@ void Channel::clearMidiBuffer()
 }
 
 
-/* -------------------------------------------------------------------------- */
-
-
-void Channel::setPluginHost(PluginHost *pluginHost)
-{
-  this->pluginHost = pluginHost;
-}
-
 #endif
