@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * channel
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,11 +25,12 @@
  * -------------------------------------------------------------------------- */
 
 
-#ifndef CHANNEL_H
-#define CHANNEL_H
+#ifndef G_CHANNEL_H
+#define G_CHANNEL_H
 
 
 #include <vector>
+#include <string>
 #include <pthread.h>
 #include "midiMapConf.h"
 #include "recorder.h"
@@ -41,8 +40,9 @@
 #endif
 
 
-using std::vector;
-using std::string;
+class Plugin;
+class MidiMapConf;
+class geChannel;
 
 
 class Channel
@@ -51,11 +51,6 @@ protected:
 
 #ifdef WITH_VST
 
-	/* pluginHost
-	 * Pointer to PluginHost class, which manages and processes plugins. */
-
-	class PluginHost *pluginHost;
-
 	/* MidiBuffer contains MIDI events. When ready, events are sent to
 	 * each plugin in the channel. This is available for any kind of
 	 * channel, but it makes sense only for MIDI channels. */
@@ -64,25 +59,33 @@ protected:
 
 #endif
 
-	/* MidiMapConf
-	 * Pointer to MidiMapConf. It deals with Midi lightning operations. */
-
-	class MidiMapConf *midiMapConf;
-
 	/* bufferSize
 	 * size of every buffer in this channel (vChan, pChan) */
 
 	int bufferSize;
 
-	/* sendMidiLMessage
-	 * compose a MIDI message by merging bytes from MidiMap conf class, and send
-	 * it to KernelMidi. */
+  /* midiFilter
+  Which MIDI channel should be filtered out when receiving MIDI messages. -1
+  means 'all'. */
 
-	void sendMidiLmessage(uint32_t learn, const MidiMapConf::message_t &msg);
+  int midiFilter;
+
+	float pan;
+
+	/* sendMidiLMessage
+	Composes a MIDI message by merging bytes from MidiMap conf class, and sends it 
+	to KernelMidi. */
+
+	void sendMidiLmessage(uint32_t learn, const giada::m::midimap::message_t &msg);
+
+	/* calcPanning
+	Given an audio channel (stereo: 0 or 1) computes the current panning value. */
+
+	float calcPanning(int ch);
 
 public:
 
-	Channel(int type, int status, int bufferSize, class MidiMapConf *midiMapConf);
+	Channel(int type, int status, int bufferSize);
 
 	virtual ~Channel();
 
@@ -94,10 +97,8 @@ public:
 	/* readPatch
 	 * Fill channel with data from patch. */
 
-	virtual int readPatch_DEPR_(const char *file, int i, class Patch_DEPR_ *patch,
-			int samplerate, int rsmpQuality) = 0;
-	virtual int readPatch(const string &basePath, int i, class Patch *patch,
-			pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality);
+	virtual int readPatch(const std::string &basePath, int i,
+    pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality);
 
 	/* process
 	Merges vChannels into buffer, plus plugin processing (if any). Warning:
@@ -146,7 +147,7 @@ public:
 	 * mixer::channels, used by recorder. LocalFrame = frame within the current
    * buffer.  */
 
-	virtual void quantize(int index, int localFrame, class Mixer *m) = 0;
+	virtual void quantize(int index, int localFrame) = 0;
 
 	/* onZero
 	 * action to do when frame goes to zero, i.e. sequencer restart. */
@@ -166,8 +167,8 @@ public:
 
 	 // TODO - quantize is useless!
 
-	virtual void parseAction(Recorder::action *a, int localFrame, int globalFrame,
-			int quantize, bool mixerIsRunning) = 0;
+	virtual void parseAction(giada::m::recorder::action *a, int localFrame,
+    int globalFrame, int quantize, bool mixerIsRunning) = 0;
 
 	/* rewind
 	 * rewind channel when rewind button is pressed. */
@@ -190,7 +191,7 @@ public:
 	 * Fill a patch with channel values. Returns the index of the last
 	 * Patch::channel_t added. */
 
-	virtual int writePatch(int i, bool isProject, class Patch *patch);
+	virtual int writePatch(int i, bool isProject);
 
 	/* receiveMidi
 	 * Receives and processes midi messages from external devices. */
@@ -206,8 +207,6 @@ public:
 	float   volume;                // global volume
 	float   volume_i;              // internal volume
 	float   volume_d;              // delta volume (for envelope)
-	float   panLeft;
-	float   panRight;
 	bool    mute_i;                // internal mute
 	bool 	  mute_s;                // previous mute status after being solo'd
 	bool    mute;                  // global mute
@@ -217,7 +216,7 @@ public:
 	bool    armed;							   // armed for recording
 	int 	  recStatus;             // status of recordings (waiting, ending, ...)
 	float  *vChan;	               // virtual channel
-  class   geChannel *guiChannel; // pointer to a gChannel object, part of the GUI
+  geChannel *guiChannel;         // pointer to a gChannel object, part of the GUI
 
 	// TODO - midi structs, please
 
@@ -241,7 +240,7 @@ public:
   uint32_t midiOutLsolo;
 
 #ifdef WITH_VST
-  vector <class Plugin *> plugins;
+  std::vector <Plugin *> plugins;
 #endif
 
 
@@ -252,13 +251,6 @@ public:
 
 	bool isPlaying();
 
-	/* readPatchMidiIn
-	 * read from patch all midi-related parameters such as keypress, mute
-	 * and so on. */
-
-	void readPatchMidiIn_DEPR_(int i, class Patch_DEPR_ &patch);
-	void readPatchMidiOut_DEPR_(int i, class Patch_DEPR_ &patch);
-
 	/* sendMidiL*
 	 * send MIDI lightning events to a physical device. */
 
@@ -266,14 +258,11 @@ public:
 	void sendMidiLsolo();
 	void sendMidiLplay();
 
+	void setPan(float v);
+	float getPan();
+
 #ifdef WITH_VST
 
-	/* SetPluginHost
-	 * A neat trick to avoid duplicated constructors (with and without pointer
-	 * to PluginHost). */
-
-	void setPluginHost(class PluginHost *pluginHost);
-
 	/* getPluginMidiEvents
 	 * Return a reference to midiBuffer stack. This is available for any kind of
 	 * channel, but it makes sense only for MIDI channels. */
