@@ -29,20 +29,31 @@
 #define G_CONST_H
 
 
-/* -- version --------------------------------------------------------------- */
-#define G_APP_NAME      "Giada"
-#define G_VERSION_STR   "0.14.0"
-#define G_VERSION_MAJOR 0
-#define G_VERSION_MINOR 14
-#define G_VERSION_PATCH 0
-
-#define CONF_FILENAME "giada.conf"
+/* -- environment ----------------------------------------------------------- */
+#if defined(_WIN32)
+	#define G_OS_WINDOWS
+#elif defined(__APPLE__)
+	#define G_OS_MAC
+#elif defined(__linux__)
+	#define G_OS_LINUX
+#endif
 
 #ifndef BUILD_DATE
 	#define BUILD_DATE __DATE__
 #endif
 
-#ifdef _WIN32
+
+
+/* -- version --------------------------------------------------------------- */
+#define G_APP_NAME      "Giada"
+#define G_VERSION_STR   "0.14.1"
+#define G_VERSION_MAJOR 0
+#define G_VERSION_MINOR 14
+#define G_VERSION_PATCH 1
+
+#define CONF_FILENAME "giada.conf"
+
+#ifdef G_OS_WINDOWS
 	#define G_SLASH '\\'
 	#define G_SLASH_STR "\\"
 #else
@@ -52,30 +63,27 @@
 
 
 /* -- GUI ------------------------------------------------------------------- */
-#ifdef _WIN32
-	#define GUI_SLEEP			1000/24
+#ifdef G_OS_WINDOWS
+	#define G_GUI_SLEEP			1000/24
 #else
-	#define GUI_SLEEP			1000000/24 // == 1.000.000 / 24 == 1/24 sec == 24 Hz
+	#define G_GUI_SLEEP			1000000/24 // == 1.000.000 / 24 == 1/24 sec == 24 Hz
 #endif
-#define GUI_WIDTH				   816
-#define GUI_HEIGHT			   510
-#define GUI_PLUGIN_RATE    0.05  // refresh rate for plugin GUIs
-#define GUI_FONT_SIZE_BASE 12
+#define G_GUI_WIDTH				   816
+#define G_GUI_HEIGHT			   510
+#define G_GUI_PLUGIN_RATE    0.05  // refresh rate for plugin GUIs
+#define G_GUI_FONT_SIZE_BASE 12
 
-#define COLOR_BD_0     fl_rgb_color(78,  78,  78)			// border off - TODO duplicate!
-#define COLOR_BD_1     fl_rgb_color(188, 188, 188)    // border on
-#define COLOR_BG_0     fl_rgb_color(37,  37,  37)     // bg off
-#define COLOR_BG_1     fl_rgb_color(78,  78,  78)     // bg on (clicked) - TODO duplicate!
-#define COLOR_BG_2     fl_rgb_color(177, 142, 142)    // bg active (play, for some widgets)
-#define COLOR_BG_3     fl_rgb_color(28,  32,  80)     // bg input rec
-#define COLOR_BG_4     fl_rgb_color(113, 31,  31)     // bg action rec
-#define COLOR_ALERT    fl_rgb_color(239, 75,  53)     // peak meter alert
-#define COLOR_TEXT_0   fl_rgb_color(200, 200, 200)
-#define COLOR_TEXT_1   fl_rgb_color(25,  25,  25)      // TODO duplicate!
-#define COLOR_BG_MAIN  fl_rgb_color(25,  25,  25)		   // windows background - TODO duplicate!
-#define COLOR_BG_RICH  fl_rgb_color(30,  30,  30)		   // lighter background
-#define COLOR_BG_LINE  fl_rgb_color(54,  54,  54)		   // lighter, for bg lines
-#define COLOR_BG_DARK  fl_rgb_color(0,   0,   0)		   // inputs background
+#define G_COLOR_RED       fl_rgb_color(28,  32,  80)
+#define G_COLOR_BLUE      fl_rgb_color(113, 31,  31)
+#define G_COLOR_RED_ALERT fl_rgb_color(239, 75,  53)
+
+#define G_COLOR_LIGHT_2 fl_rgb_color(200, 200, 200)
+#define G_COLOR_LIGHT_1 fl_rgb_color(170, 170, 170)
+#define G_COLOR_GREY_4  fl_rgb_color(78,  78,  78)
+#define G_COLOR_GREY_3  fl_rgb_color(54,  54,  54)
+#define G_COLOR_GREY_2  fl_rgb_color(37,  37,  37)
+#define G_COLOR_GREY_1  fl_rgb_color(25,  25,  25)
+#define G_COLOR_BLACK   fl_rgb_color(0,   0,   0)
 
 
 
@@ -86,7 +94,7 @@
 #define G_MAX_BARS				  32
 #define G_MAX_QUANTIZE      8
 #define G_MAX_PATCHNAME_LEN	32
-#define G_DB_MIN_SCALE      60.0f
+#define G_MIN_DB_SCALE      60.0f
 #define G_MIN_COLUMN_WIDTH  140
 #define G_MAX_BOOST_DB      20.0f
 #define G_MAX_PITCH         4.0f
@@ -113,11 +121,11 @@
 
 
 /* -- default system -------------------------------------------------------- */
-#if defined(__linux__)
+#if defined(G_OS_LINUX)
 	#define G_DEFAULT_SOUNDSYS	G_SYS_API_NONE
-#elif defined(_WIN32)
+#elif defined(G_OS_WINDOWS)
 	#define G_DEFAULT_SOUNDSYS 	G_SYS_API_DS
-#elif defined(__APPLE__)
+#elif defined(G_OS_MAC)
 	#define G_DEFAULT_SOUNDSYS 	G_SYS_API_CORE
 #endif
 
