@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * init
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,15 +25,8 @@
  * -------------------------------------------------------------------------- */
 
 
-#ifndef INIT_H
-#define INIT_H
-
-
-#include <cstdio>
-#include <stdint.h>
-#ifdef __APPLE__
-	#include <pwd.h>
-#endif
+#ifndef G_INIT_H
+#define G_INIT_H
 
 
 void init_prepareParser();
