@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * KernelMidi
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,10 +25,11 @@
  * -------------------------------------------------------------------------- */
 
 
-#include <RtMidi.h>
+#include <rtmidi/RtMidi.h>
 #include "../utils/log.h"
 #include "../glue/channel.h"
 #include "../glue/main.h"
+#include "../glue/transport.h"
 #include "../glue/io.h"
 #include "mixer.h"
 #include "const.h"
@@ -46,342 +45,71 @@
 #include "kernelMidi.h"
 
 
-extern bool        G_midiStatus;
-extern Conf        G_Conf;
-extern Mixer       G_Mixer;
-extern KernelMidi  G_KernelMidi;
-extern MidiMapConf G_MidiMap;
-#ifdef WITH_VST
-extern PluginHost  G_PluginHost;
-#endif
-
 using std::string;
 using std::vector;
 
 
-KernelMidi::KernelMidi()
-	:	numOutPorts(0),
-		numInPorts (0),
-		api        (0),      // one api for both in & out
-		midiOut    (nullptr),
-		midiIn     (nullptr),
-		cb_learn   (nullptr),
-		cb_data    (nullptr)
+namespace giada {
+namespace m {
+namespace kernelMidi
 {
-}
+namespace
+{
+bool status = false;
+int api = 0;
+RtMidiOut *midiOut = nullptr;
+RtMidiIn  *midiIn  = nullptr;
+unsigned numOutPorts = 0;
+unsigned numInPorts  = 0;
+
+/* cb_learn
+ * callback prepared by the gdMidiGrabber window and called by
+ * kernelMidi. It contains things to do once the midi message has been
+ * stored. */
+
+cb_midiLearn *cb_learn = nullptr;
+void         *cb_data  = nullptr;
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void KernelMidi::callback(double t, vector<unsigned char> *msg, void *data)
+#ifdef WITH_VST
+
+void processPlugins(Channel *ch, uint32_t pure, uint32_t value)
 {
-	G_KernelMidi.__callback(t, msg, data);
-}
+  /* Plugins' parameters layout reflect the structure of the matrix
+  Channel::midiInPlugins. It is safe to assume then that i and k indexes match
+  both the structure of Channel::midiInPlugins and vector <Plugin *> *plugins. */
 
+  vector <Plugin *> *plugins = pluginHost::getStack(pluginHost::CHANNEL, ch);
 
-/* -------------------------------------------------------------------------- */
-
-
-void KernelMidi::sendMidiLightningInitMsgs()
-{
-	for(unsigned i=0; i<G_MidiMap.initCommands.size(); i++) {
-		MidiMapConf::message_t msg = G_MidiMap.initCommands.at(i);
-		if (msg.value != 0x0 && msg.channel != -1) {
-			gu_log("[KM] MIDI send (init) - Channel %x - Event 0x%X\n", msg.channel, msg.value);
-			send(msg.value | MIDI_CHANS[msg.channel]);
-		}
-	}
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void KernelMidi::startMidiLearn(cb_midiLearn *cb, void *data)
-{
-	cb_learn = cb;
-	cb_data  = data;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void KernelMidi::stopMidiLearn()
-{
-	cb_learn = nullptr;
-	cb_data  = nullptr;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void KernelMidi::setApi(int _api)
-{
-	api = _api;
-	gu_log("[KM] using system 0x%x\n", api);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-int KernelMidi::openOutDevice(int port)
-{
-	try {
-		midiOut = new RtMidiOut((RtMidi::Api) api, "Giada MIDI Output");
-		G_midiStatus = true;
+  for (unsigned i=0; i<plugins->size(); i++)
+  {
+    Plugin *plugin = plugins->at(i);
+    for (unsigned k=0; k<plugin->midiInParams.size(); k++) {
+      uint32_t midiInParam = plugin->midiInParams.at(k);
+      if (pure != midiInParam)
+        continue;
+      float vf = (value >> 8)/127.0f;
+      plugin->setParameter(k, vf);
+      gu_log("  >>> [plugin %d parameter %d] ch=%d (pure=0x%X, value=%d, float=%f)\n",
+        i, k, ch->index, pure, value >> 8, vf);
+    }
   }
-  catch (RtMidiError &error) {
-    gu_log("[KM] MIDI out device error: %s\n", error.getMessage().c_str());
-    G_midiStatus = false;
-    return 0;
-  }
-
-	/* print output ports */
-
-	numOutPorts = midiOut->getPortCount();
-  gu_log("[KM] %d output MIDI ports found\n", numOutPorts);
-  for (unsigned i=0; i<numOutPorts; i++)
-		gu_log("  %d) %s\n", i, getOutPortName(i).c_str());
-
-	/* try to open a port, if enabled */
-
-	if (port != -1 && numOutPorts > 0) {
-		try {
-			midiOut->openPort(port, getOutPortName(port));
-			gu_log("[KM] MIDI out port %d open\n", port);
-
-			/* TODO - it shold send midiLightning message only if there is a map loaded
-			and available in G_MidiMap. */
-
-			sendMidiLightningInitMsgs();
-			return 1;
-		}
-		catch (RtMidiError &error) {
-			gu_log("[KM] unable to open MIDI out port %d: %s\n", port, error.getMessage().c_str());
-			G_midiStatus = false;
-			return 0;
-		}
-	}
-	else
-		return 2;
 }
 
+#endif
+
 
 /* -------------------------------------------------------------------------- */
 
 
-int KernelMidi::openInDevice(int port)
+void processChannels(uint32_t pure, uint32_t value)
 {
-	try {
-		midiIn = new RtMidiIn((RtMidi::Api) api, "Giada MIDI input");
-		G_midiStatus = true;
-  }
-  catch (RtMidiError &error) {
-    gu_log("[KM] MIDI in device error: %s\n", error.getMessage().c_str());
-    G_midiStatus = false;
-    return 0;
-  }
+	for (unsigned i=0; i<mixer::channels.size(); i++) {
 
-	/* print input ports */
-
-	numInPorts = midiIn->getPortCount();
-  gu_log("[KM] %d input MIDI ports found\n", numInPorts);
-  for (unsigned i=0; i<numInPorts; i++)
-		gu_log("  %d) %s\n", i, getInPortName(i).c_str());
-
-	/* try to open a port, if enabled */
-
-	if (port != -1 && numInPorts > 0) {
-		try {
-			midiIn->openPort(port, getInPortName(port));
-			midiIn->ignoreTypes(true, false, true); // ignore all system/time msgs, for now
-			gu_log("[KM] MIDI in port %d open\n", port);
-			midiIn->setCallback(&callback);
-			return 1;
-		}
-		catch (RtMidiError &error) {
-			gu_log("[KM] unable to open MIDI in port %d: %s\n", port, error.getMessage().c_str());
-			G_midiStatus = false;
-			return 0;
-		}
-	}
-	else
-		return 2;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-bool KernelMidi::hasAPI(int API)
-{
-	vector<RtMidi::Api> APIs;
-	RtMidi::getCompiledApi(APIs);
-	for (unsigned i=0; i<APIs.size(); i++)
-		if (APIs.at(i) == API)
-			return true;
-	return false;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-string KernelMidi::getOutPortName(unsigned p)
-{
-	try { return midiOut->getPortName(p); }
-	catch (RtMidiError &error) { return ""; }
-}
-
-string KernelMidi::getInPortName(unsigned p)
-{
-	try { return midiIn->getPortName(p); }
-	catch (RtMidiError &error) { return ""; }
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void KernelMidi::send(uint32_t data)
-{
-	if (!G_midiStatus)
-		return;
-
-  vector<unsigned char> msg(1, getB1(data));
-  msg.push_back(getB2(data));
-  msg.push_back(getB3(data));
-
-	midiOut->sendMessage(&msg);
-	gu_log("[KM] send msg=0x%X (%X %X %X)\n", data, msg[0], msg[1], msg[2]);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void KernelMidi::send(int b1, int b2, int b3)
-{
-	if (!G_midiStatus)
-		return;
-
-	vector<unsigned char> msg(1, b1);
-
-	if (b2 != -1)
-		msg.push_back(b2);
-	if (b3 != -1)
-		msg.push_back(b3);
-
-	midiOut->sendMessage(&msg);
-	//gu_log("[KM] send msg=(%X %X %X)\n", b1, b2, b3);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void KernelMidi::__callback(double t, vector<unsigned char> *msg, void *data)
-{
-	/* 0.8.0 - for now we handle other midi signals (common and real-time
-	 * messages) as unknown, for debugging purposes */
-
-	if (msg->size() < 3) {
-		gu_log("[KM] MIDI received - unknown signal - size=%d, value=0x", (int) msg->size());
-		for (unsigned i=0; i<msg->size(); i++)
-			gu_log("%X", (int) msg->at(i));
-		gu_log("\n");
-		return;
-	}
-
-	/* in this place we want to catch two things: a) note on/note off
-	 * from a keyboard and b) knob/wheel/slider movements from a
-	 * controller */
-
-	uint32_t input = getIValue(msg->at(0), msg->at(1), msg->at(2));
-	uint32_t chan  = input & 0x0F000000;
-	uint32_t value = input & 0x0000FF00;
-	uint32_t pure  = 0x00;
-	if (!G_Conf.noNoteOff)
-		pure = input & 0xFFFF0000;   // input without 'value' byte
-	else
-		pure = input & 0xFFFFFF00;   // input with 'value' byte
-
-	gu_log("[KM] MIDI received - 0x%X (chan %d)\n", input, chan >> 24);
-
-	/* start dispatcher. If midi learn is on don't parse channels, just
-	 * learn incoming midi signal. Otherwise process master events first,
-	 * then each channel in the stack. This way incoming signals don't
-	 * get processed by glue_* when midi learning is on. */
-
-	if (cb_learn)
-		cb_learn(pure, cb_data);
-	else {
-		processMaster(pure, value);
-		processChannels(pure, value);
-	}
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void KernelMidi::processMaster(uint32_t pure, uint32_t value)
-{
-	if      (pure == G_Conf.midiInRewind) {
-		gu_log("  >>> rewind (master) (pure=0x%X)\n", pure);
-		glue_rewindSeq();
-	}
-	else if (pure == G_Conf.midiInStartStop) {
-		gu_log("  >>> startStop (master) (pure=0x%X)\n", pure);
-		glue_startStopSeq(false);
-	}
-	else if (pure == G_Conf.midiInActionRec) {
-		gu_log("  >>> actionRec (master) (pure=0x%X)\n", pure);
-		glue_startStopActionRec(false);
-	}
-	else if (pure == G_Conf.midiInInputRec) {
-		gu_log("  >>> inputRec (master) (pure=0x%X)\n", pure);
-		glue_startStopInputRec(false);
-	}
-	else if (pure == G_Conf.midiInMetronome) {
-		gu_log("  >>> metronome (master) (pure=0x%X)\n", pure);
-		glue_startStopMetronome(false);
-	}
-	else if (pure == G_Conf.midiInVolumeIn) {
-		float vf = (value >> 8)/127.0f;
-		gu_log("  >>> input volume (master) (pure=0x%X, value=%d, float=%f)\n",
-			pure, value >> 8, vf);
-		glue_setInVol(vf, false);
-	}
-	else if (pure == G_Conf.midiInVolumeOut) {
-		float vf = (value >> 8)/127.0f;
-		gu_log("  >>> output volume (master) (pure=0x%X, value=%d, float=%f)\n",
-			pure, value >> 8, vf);
-		glue_setOutVol(vf, false);
-	}
-	else if (pure == G_Conf.midiInBeatDouble) {
-		gu_log("  >>> sequencer x2 (master) (pure=0x%X)\n", pure);
-		glue_beatsMultiply();
-	}
-	else if (pure == G_Conf.midiInBeatHalf) {
-		gu_log("  >>> sequencer /2 (master) (pure=0x%X)\n", pure);
-		glue_beatsDivide();
-	}
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void KernelMidi::processChannels(uint32_t pure, uint32_t value)
-{
-	for (unsigned i=0; i<G_Mixer.channels.size(); i++) {
-
-		Channel *ch = (Channel*) G_Mixer.channels.at(i);
+		Channel *ch = static_cast<SampleChannel*>(mixer::channels.at(i));
 
 		if (!ch->midiIn)
 			continue;
@@ -406,29 +134,24 @@ void KernelMidi::processChannels(uint32_t pure, uint32_t value)
 			float vf = (value >> 8)/127.0f;
 			gu_log("  >>> volume ch=%d (pure=0x%X, value=%d, float=%f)\n",
 				ch->index, pure, value >> 8, vf);
-			glue_setChanVol(ch, vf, false);
+			glue_setVolume(ch, vf, false);
 		}
 		else if (pure == ((SampleChannel*)ch)->midiInPitch) {
 			float vf = (value >> 8)/(127/4.0f); // [0-127] ~> [0.0 4.0]
 			gu_log("  >>> pitch ch=%d (pure=0x%X, value=%d, float=%f)\n",
 				ch->index, pure, value >> 8, vf);
-			glue_setPitch(nullptr, (SampleChannel*)ch, vf, false);
+			glue_setPitch(static_cast<SampleChannel*>(ch), vf);
 		}
 		else if (pure == ((SampleChannel*)ch)->midiInReadActions) {
 			gu_log("  >>> start/stop read actions ch=%d (pure=0x%X)\n", ch->index, pure);
-			glue_startStopReadingRecs((SampleChannel*)ch, false);
+			glue_startStopReadingRecs(static_cast<SampleChannel*>(ch), false);
 		}
 
 #ifdef WITH_VST
-
-    /* Process plugins' parameters */
-
-    processPlugins(ch, pure, value);
-
+    processPlugins(ch, pure, value); // Process plugins' parameters
 #endif
 
 		/* Redirect full midi message (pure + value) to plugins */
-
 		ch->receiveMidi(pure | value);
 	}
 }
@@ -437,38 +160,346 @@ void KernelMidi::processChannels(uint32_t pure, uint32_t value)
 /* -------------------------------------------------------------------------- */
 
 
-#ifdef WITH_VST
-
-void KernelMidi::processPlugins(Channel *ch, uint32_t pure, uint32_t value)
+void processMaster(uint32_t pure, uint32_t value)
 {
-  /* Plugins' parameters layout reflect the structure of the matrix
-  Channel::midiInPlugins. It is safe to assume then that i and k indexes match
-  both the structure of Channel::midiInPlugins and vector <Plugin *> *plugins. */
-
-  vector <Plugin *> *plugins = G_PluginHost.getStack(PluginHost::CHANNEL, ch);
-
-  for (unsigned i=0; i<plugins->size(); i++)
-  {
-    Plugin *plugin = plugins->at(i);
-    for (unsigned k=0; k<plugin->midiInParams.size(); k++) {
-      uint32_t midiInParam = plugin->midiInParams.at(k);
-      if (pure != midiInParam)
-        continue;
-      float vf = (value >> 8)/127.0f;
-      plugin->setParameter(k, vf);
-      gu_log("  >>> [plugin %d parameter %d] ch=%d (pure=0x%X, value=%d, float=%f)\n",
-        i, k, ch->index, pure, value >> 8, vf);
-    }
-  }
+  if      (pure == conf::midiInRewind) {
+		gu_log("  >>> rewind (master) (pure=0x%X)\n", pure);
+		glue_rewindSeq(false);
+	}
+	else if (pure == conf::midiInStartStop) {
+		gu_log("  >>> startStop (master) (pure=0x%X)\n", pure);
+		glue_startStopSeq(false);
+	}
+	else if (pure == conf::midiInActionRec) {
+		gu_log("  >>> actionRec (master) (pure=0x%X)\n", pure);
+		glue_startStopActionRec(false);
+	}
+	else if (pure == conf::midiInInputRec) {
+		gu_log("  >>> inputRec (master) (pure=0x%X)\n", pure);
+		glue_startStopInputRec(false);
+	}
+	else if (pure == conf::midiInMetronome) {
+		gu_log("  >>> metronome (master) (pure=0x%X)\n", pure);
+		glue_startStopMetronome(false);
+	}
+	else if (pure == conf::midiInVolumeIn) {
+		float vf = (value >> 8)/127.0f;
+		gu_log("  >>> input volume (master) (pure=0x%X, value=%d, float=%f)\n",
+			pure, value >> 8, vf);
+		glue_setInVol(vf, false);
+	}
+	else if (pure == conf::midiInVolumeOut) {
+		float vf = (value >> 8)/127.0f;
+		gu_log("  >>> output volume (master) (pure=0x%X, value=%d, float=%f)\n",
+			pure, value >> 8, vf);
+		glue_setOutVol(vf, false);
+	}
+	else if (pure == conf::midiInBeatDouble) {
+		gu_log("  >>> sequencer x2 (master) (pure=0x%X)\n", pure);
+		glue_beatsMultiply();
+	}
+	else if (pure == conf::midiInBeatHalf) {
+		gu_log("  >>> sequencer /2 (master) (pure=0x%X)\n", pure);
+		glue_beatsDivide();
+	}
 }
 
-#endif
-
 
 /* -------------------------------------------------------------------------- */
 
 
-string KernelMidi::getRtMidiVersion()
+static void callback(double t, std::vector<unsigned char> *msg, void *data)
 {
-	return midiOut->getVersion();
+  /* 0.8.0 - for now we handle other midi signals (common and real-time
+	 * messages) as unknown, for debugging purposes */
+
+	if (msg->size() < 3) {
+		gu_log("[KM] MIDI received - unknown signal - size=%d, value=0x", (int) msg->size());
+		for (unsigned i=0; i<msg->size(); i++)
+			gu_log("%X", (int) msg->at(i));
+		gu_log("\n");
+		return;
+	}
+
+	/* in this place we want to catch two things: a) note on/note off
+	 * from a keyboard and b) knob/wheel/slider movements from a
+	 * controller */
+
+	uint32_t input = getIValue(msg->at(0), msg->at(1), msg->at(2));
+	uint32_t chan  = input & 0x0F000000;
+	uint32_t value = input & 0x0000FF00;
+	uint32_t pure  = 0x00;
+	if (!conf::noNoteOff)
+		pure = input & 0xFFFF0000;   // input without 'value' byte
+	else
+		pure = input & 0xFFFFFF00;   // input with 'value' byte
+
+	gu_log("[KM] MIDI received - 0x%X (chan %d)\n", input, chan >> 24);
+
+	/* start dispatcher. If midi learn is on don't parse channels, just
+	 * learn incoming midi signal. Otherwise process master events first,
+	 * then each channel in the stack. This way incoming signals don't
+	 * get processed by glue_* when midi learning is on. */
+
+	if (cb_learn)
+		cb_learn(pure, cb_data);
+	else {
+		processMaster(pure, value);
+		processChannels(pure, value);
+	}
 }
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void sendMidiLightningInitMsgs()
+{
+  for(unsigned i=0; i<midimap::initCommands.size(); i++) {
+		midimap::message_t msg = midimap::initCommands.at(i);
+		if (msg.value != 0x0 && msg.channel != -1) {
+			gu_log("[KM] MIDI send (init) - Channel %x - Event 0x%X\n", msg.channel, msg.value);
+			send(msg.value | MIDI_CHANS[msg.channel]);
+		}
+	}
+}
+
+}; // {anonymous}
+
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+
+void startMidiLearn(cb_midiLearn *cb, void *data)
+{
+	cb_learn = cb;
+	cb_data  = data;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void stopMidiLearn()
+{
+	cb_learn = nullptr;
+	cb_data  = nullptr;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void setApi(int _api)
+{
+	api = _api;
+	gu_log("[KM] using system 0x%x\n", api);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+int openOutDevice(int port)
+{
+	try {
+		midiOut = new RtMidiOut((RtMidi::Api) api, "Giada MIDI Output");
+		status = true;
+  }
+  catch (RtMidiError &error) {
+    gu_log("[KM] MIDI out device error: %s\n", error.getMessage().c_str());
+    status = false;
+    return 0;
+  }
+
+	/* print output ports */
+
+	numOutPorts = midiOut->getPortCount();
+  gu_log("[KM] %d output MIDI ports found\n", numOutPorts);
+  for (unsigned i=0; i<numOutPorts; i++)
+		gu_log("  %d) %s\n", i, getOutPortName(i).c_str());
+
+	/* try to open a port, if enabled */
+
+	if (port != -1 && numOutPorts > 0) {
+		try {
+			midiOut->openPort(port, getOutPortName(port));
+			gu_log("[KM] MIDI out port %d open\n", port);
+
+			/* TODO - it shold send midiLightning message only if there is a map loaded
+			and available in midimap:: */
+
+			sendMidiLightningInitMsgs();
+			return 1;
+		}
+		catch (RtMidiError &error) {
+			gu_log("[KM] unable to open MIDI out port %d: %s\n", port, error.getMessage().c_str());
+			status = false;
+			return 0;
+		}
+	}
+	else
+		return 2;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+int openInDevice(int port)
+{
+	try {
+		midiIn = new RtMidiIn((RtMidi::Api) api, "Giada MIDI input");
+		status = true;
+  }
+  catch (RtMidiError &error) {
+    gu_log("[KM] MIDI in device error: %s\n", error.getMessage().c_str());
+    status = false;
+    return 0;
+  }
+
+	/* print input ports */
+
+	numInPorts = midiIn->getPortCount();
+  gu_log("[KM] %d input MIDI ports found\n", numInPorts);
+  for (unsigned i=0; i<numInPorts; i++)
+		gu_log("  %d) %s\n", i, getInPortName(i).c_str());
+
+	/* try to open a port, if enabled */
+
+	if (port != -1 && numInPorts > 0) {
+		try {
+			midiIn->openPort(port, getInPortName(port));
+			midiIn->ignoreTypes(true, false, true); // ignore all system/time msgs, for now
+			gu_log("[KM] MIDI in port %d open\n", port);
+			midiIn->setCallback(&callback);
+			return 1;
+		}
+		catch (RtMidiError &error) {
+			gu_log("[KM] unable to open MIDI in port %d: %s\n", port, error.getMessage().c_str());
+			status = false;
+			return 0;
+		}
+	}
+	else
+		return 2;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+bool hasAPI(int API)
+{
+	vector<RtMidi::Api> APIs;
+	RtMidi::getCompiledApi(APIs);
+	for (unsigned i=0; i<APIs.size(); i++)
+		if (APIs.at(i) == API)
+			return true;
+	return false;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+string getOutPortName(unsigned p)
+{
+	try { return midiOut->getPortName(p); }
+	catch (RtMidiError &error) { return ""; }
+}
+
+string getInPortName(unsigned p)
+{
+	try { return midiIn->getPortName(p); }
+	catch (RtMidiError &error) { return ""; }
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void send(uint32_t data)
+{
+	if (!status)
+		return;
+
+  vector<unsigned char> msg(1, getB1(data));
+  msg.push_back(getB2(data));
+  msg.push_back(getB3(data));
+
+	midiOut->sendMessage(&msg);
+	gu_log("[KM] send msg=0x%X (%X %X %X)\n", data, msg[0], msg[1], msg[2]);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void send(int b1, int b2, int b3)
+{
+	if (!status)
+		return;
+
+	vector<unsigned char> msg(1, b1);
+
+	if (b2 != -1)
+		msg.push_back(b2);
+	if (b3 != -1)
+		msg.push_back(b3);
+
+	midiOut->sendMessage(&msg);
+	//gu_log("[KM] send msg=(%X %X %X)\n", b1, b2, b3);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+unsigned countInPorts()
+{
+  return numInPorts;
+}
+
+
+unsigned countOutPorts()
+{
+  return numOutPorts;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+int getB1(uint32_t iValue) { return (iValue >> 24) & 0xFF; }
+int getB2(uint32_t iValue) { return (iValue >> 16) & 0xFF; }
+int getB3(uint32_t iValue) { return (iValue >> 8)  & 0xFF; }
+
+
+uint32_t getIValue(int b1, int b2, int b3)
+{
+  return (b1 << 24) | (b2 << 16) | (b3 << 8) | (0x00);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+uint32_t setChannel(uint32_t iValue, int channel)
+{
+  uint32_t chanMask = 0xF << 24;
+  return (iValue & (~chanMask)) | (channel << 24);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+bool getStatus()
+{
+	return status;
+}
+
+}}}; // giada::m::kernelMidi::
