@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * channel
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,22 +25,25 @@
  * -------------------------------------------------------------------------- */
 
 
-#ifndef MIDI_CHANNEL_H
-#define MIDI_CHANNEL_H
+#ifndef G_MIDI_CHANNEL_H
+#define G_MIDI_CHANNEL_H
 
 
 #ifdef WITH_VST
 	#include "../deps/juce-config.h"
 #endif
-
 #include "channel.h"
 
 
+class MidiMapConf;
+class Patch;
+
+
 class MidiChannel : public Channel
 {
 public:
 
-	MidiChannel(int bufferSize, class MidiMapConf *midiMapConf);
+	MidiChannel(int bufferSize);
 	~MidiChannel();
 
   bool    midiOut;           // enable midi output
@@ -60,15 +61,13 @@ public:
 	void rewind() override;
 	void setMute(bool internal) override;
 	void unsetMute(bool internal) override;
-	int readPatch_DEPR_(const char *file, int i, class Patch_DEPR_ *patch,
-			int samplerate, int rsmpQuality) override;
-	int readPatch(const string &basePath, int i, class Patch *patch,
-			pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality) override;
-	int writePatch(int i, bool isProject, class Patch *patch) override;
-	void quantize(int index, int localFrame, class Mixer *m) override;
+	int readPatch(const std::string &basePath, int i, pthread_mutex_t *pluginMutex,
+    int samplerate, int rsmpQuality) override;
+	int writePatch(int i, bool isProject) override;
+	void quantize(int index, int localFrame) override;
 	void onZero(int frame, bool recsStopOnChanHalt) override;
 	void onBar(int frame) override;
-	void parseAction(Recorder::action *a, int localFrame, int globalFrame,
+	void parseAction(giada::m::recorder::action *a, int localFrame, int globalFrame,
 			int quantize, bool mixerIsRunning) override;
 	void receiveMidi(uint32_t msg) override;
 	bool canInputRec() override;
@@ -78,7 +77,7 @@ public:
 	/* sendMidi
 	 * send Midi event to the outside world. */
 
-	void sendMidi(Recorder::action *a, int localFrame);
+	void sendMidi(giada::m::recorder::action *a, int localFrame);
 	void sendMidi(uint32_t data);
 
 #ifdef WITH_VST
