@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * channel
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,13 +25,16 @@
  * -------------------------------------------------------------------------- */
 
 
-#include <math.h>
+#include <cmath>
+#include <cstring>
 #include "../utils/log.h"
+#include "../utils/fs.h"
 #include "../utils/string.h"
 #include "sampleChannel.h"
-#include "patch_DEPR_.h"
 #include "patch.h"
+#include "const.h"
 #include "conf.h"
+#include "clock.h"
 #include "mixer.h"
 #include "wave.h"
 #include "pluginHost.h"
@@ -44,34 +45,32 @@
 
 
 using std::string;
+using namespace giada::m;
 
 
-extern Recorder    G_Recorder;
-extern KernelAudio G_KernelAudio;
-
-
-SampleChannel::SampleChannel(int bufferSize, MidiMapConf *midiMapConf)
-	: Channel          (CHANNEL_SAMPLE, STATUS_EMPTY, bufferSize, midiMapConf),
+SampleChannel::SampleChannel(int bufferSize, bool inputMonitor)
+	: Channel          (CHANNEL_SAMPLE, STATUS_EMPTY, bufferSize),
 		frameRewind      (-1),
-		wave             (NULL),
+		boost            (G_DEFAULT_BOOST),
+		pitch            (G_DEFAULT_PITCH),
+		wave             (nullptr),
 		tracker          (0),
 		begin            (0),
 		end              (0),
-		pitch            (G_DEFAULT_PITCH),
-		boost            (1.0f),
-		mode             (DEFAULT_CHANMODE),
+		mode             (G_DEFAULT_CHANMODE),
 		qWait	           (false),
 		fadeinOn         (false),
 		fadeinVol        (1.0f),
 		fadeoutOn        (false),
 		fadeoutVol       (1.0f),
 		fadeoutTracker   (0),
-		fadeoutStep      (DEFAULT_FADEOUT_STEP),
+		fadeoutStep      (G_DEFAULT_FADEOUT_STEP),
+    inputMonitor     (inputMonitor),
 	  midiInReadActions(0x0),
 	  midiInPitch      (0x0)
 {
-	rsmp_state = src_new(SRC_LINEAR, 2, NULL);
-	pChan      = (float *) malloc(G_KernelAudio.realBufsize * 2 * sizeof(float));
+	rsmp_state = src_new(SRC_LINEAR, 2, nullptr);
+	pChan = (float *) malloc(kernelAudio::getRealBufSize() * 2 * sizeof(float));
 }
 
 
@@ -125,7 +124,7 @@ void SampleChannel::generateUniqueSampleName()
 {
 	string oldName = wave->name;
 	int k = 1; // Start from k = 1, zero is too nerdy
-	while (!mh_uniqueSampleName(this, wave->name)) {
+	while (!mh::uniqueSampleName(this, wave->name)) {
 		wave->updateName((oldName + "-" + gu_itoa(k)).c_str());
 		k++;
 	}
@@ -140,8 +139,8 @@ void SampleChannel::clear()
 	/** TODO - these memsets can be done only if status PLAY (if below),
 	 * but it would require extra clearPChan calls when samples stop */
 
-		memset(vChan, 0, sizeof(float) * bufferSize);
-		memset(pChan, 0, sizeof(float) * bufferSize);
+		std::memset(vChan, 0, sizeof(float) * bufferSize);
+		std::memset(pChan, 0, sizeof(float) * bufferSize);
 
 	if (status & (STATUS_PLAY | STATUS_ENDING)) {
 		tracker = fillChan(vChan, tracker, 0);
@@ -160,26 +159,26 @@ void SampleChannel::calcVolumeEnv(int frame)
 {
 	/* method: check this frame && next frame, then calculate delta */
 
-	Recorder::action *a0 = NULL;
-	Recorder::action *a1 = NULL;
+	recorder::action *a0 = nullptr;
+	recorder::action *a1 = nullptr;
 	int res;
 
 	/* get this action on frame 'frame'. It's unlikely that the action
 	 * is not found. */
 
-	res = G_Recorder.getAction(index, ACTION_VOLUME, frame, &a0);
+	res = recorder::getAction(index, G_ACTION_VOLUME, frame, &a0);
 	if (res == 0)
 		return;
 
 	/* get the action next to this one.
 	 * res == -1: a1 not found, this is the last one. Rewind the search
 	 * and use action at frame number 0 (actions[0]).
-	 * res == -2 ACTION_VOLUME not found. This should never happen */
+	 * res == -2 G_ACTION_VOLUME not found. This should never happen */
 
-	res = G_Recorder.getNextAction(index, ACTION_VOLUME, frame, &a1);
+	res = recorder::getNextAction(index, G_ACTION_VOLUME, frame, &a1);
 
 	if (res == -1)
-		res = G_Recorder.getAction(index, ACTION_VOLUME, 0, &a1);
+		res = recorder::getAction(index, G_ACTION_VOLUME, 0, &a1);
 
 	volume_i = a0->fValue;
 	volume_d = ((a1->fValue - a0->fValue) / ((a1->frame - a0->frame) / 2)) * 1.003f;
@@ -236,9 +235,18 @@ int SampleChannel::save(const char *path)
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::setBegin(unsigned v)
+void SampleChannel::setBegin(int v)
 {
-	begin   = v;
+	if (v < 0)
+		begin = 0;
+	else
+	if (v > wave->size)
+		begin = wave->size - 2;
+	else
+	if (v >= end)
+		begin = end - 2;
+	else
+		begin = v;
 	tracker = begin;
 }
 
@@ -246,9 +254,18 @@ void SampleChannel::setBegin(unsigned v)
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::setEnd(unsigned v)
+void SampleChannel::setEnd(int v)
 {
-	end = v;
+	if (v < 0)
+		end = begin + 2;
+	else
+	if (v > wave->size)
+		end = wave->size;
+	else
+	if (v <= begin)
+		end = begin + 2;
+	else
+		end = v;
 }
 
 
@@ -257,7 +274,14 @@ void SampleChannel::setEnd(unsigned v)
 
 void SampleChannel::setPitch(float v)
 {
-	pitch = v;
+	if (v > G_MAX_PITCH)
+		pitch = G_MAX_PITCH;
+	else
+	if (v < 0.1f)
+		pitch = 0.1000f;
+	else 
+		pitch = v;
+
 	rsmp_data.src_ratio = 1/pitch;
 
 	/* if status is off don't slide between frequencies */
@@ -267,6 +291,12 @@ void SampleChannel::setPitch(float v)
 }
 
 
+float SampleChannel::getPitch()
+{
+	return pitch;
+}
+
+
 /* -------------------------------------------------------------------------- */
 
 
@@ -274,7 +304,7 @@ void SampleChannel::rewind()
 {
 	/* rewind LOOP_ANY or SINGLE_ANY only if it's in read-record-mode */
 
-	if (wave != NULL) {
+	if (wave != nullptr) {
 		if ((mode & LOOP_ANY) || (recStatus == REC_READING && (mode & SINGLE_ANY)))
 			reset(0);  // rewind is user-generated events, always on frame 0
 	}
@@ -284,32 +314,32 @@ void SampleChannel::rewind()
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::parseAction(Recorder::action *a, int localFrame,
+void SampleChannel::parseAction(recorder::action *a, int localFrame,
 		int globalFrame, int quantize, bool mixerIsRunning)
 {
 	if (readActions == false)
 		return;
 
 	switch (a->type) {
-		case ACTION_KEYPRESS:
+		case G_ACTION_KEYPRESS:
 			if (mode & SINGLE_ANY)
 				start(localFrame, false, quantize, mixerIsRunning, false, false);
 			break;
-		case ACTION_KEYREL:
+		case G_ACTION_KEYREL:
 			if (mode & SINGLE_ANY)
 				stop();
 			break;
-		case ACTION_KILLCHAN:
+		case G_ACTION_KILL:
 			if (mode & SINGLE_ANY)
 				kill(localFrame);
 			break;
-		case ACTION_MUTEON:
+		case G_ACTION_MUTEON:
 			setMute(true);   // internal mute
 			break;
-		case ACTION_MUTEOFF:
+		case G_ACTION_MUTEOFF:
 			unsetMute(true); // internal mute
 			break;
-		case ACTION_VOLUME:
+		case G_ACTION_VOLUME:
 			calcVolumeEnv(globalFrame);
 			break;
 	}
@@ -321,7 +351,7 @@ void SampleChannel::parseAction(Recorder::action *a, int localFrame,
 
 void SampleChannel::sum(int frame, bool running)
 {
-	if (wave == NULL || status & ~(STATUS_PLAY | STATUS_ENDING))
+	if (wave == nullptr || status & ~(STATUS_PLAY | STATUS_ENDING))
 		return;
 
 	if (frame != frameRewind) {
@@ -434,7 +464,7 @@ void SampleChannel::sum(int frame, bool running)
 
 void SampleChannel::onZero(int frame, bool recsStopOnChanHalt)
 {
-	if (wave == NULL)
+	if (wave == nullptr)
 		return;
 
 	if (mode & LOOP_ANY) {
@@ -477,7 +507,7 @@ void SampleChannel::onZero(int frame, bool recsStopOnChanHalt)
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::quantize(int index, int localFrame, Mixer *mixer)
+void SampleChannel::quantize(int index, int localFrame)
 {
 	/* skip if LOOP_ANY or not in quantizer-wait mode */
 
@@ -500,14 +530,14 @@ void SampleChannel::quantize(int index, int localFrame, Mixer *mixer)
 	/* this is the moment in which we record the keypress, if the
 	 * quantizer is on. SINGLE_PRESS needs overdub */
 
-	if (G_Recorder.canRec(this, mixer)) {
+	if (recorder::canRec(this, clock::isRunning(), mixer::recording)) {
 		if (mode == SINGLE_PRESS) {
-			G_Recorder.startOverdub(index, ACTION_KEYS, mixer->currentFrame,
-        G_KernelAudio.realBufsize);
+			recorder::startOverdub(index, G_ACTION_KEYS, clock::getCurrentFrame(),
+        kernelAudio::getRealBufSize());
       readActions = false;   // don't read actions while overdubbing
     }
 		else
-			G_Recorder.rec(index, ACTION_KEYPRESS, mixer->currentFrame);
+			recorder::rec(index, G_ACTION_KEYPRESS, clock::getCurrentFrame());
     hasActions = true;
 	}
 }
@@ -599,12 +629,33 @@ void SampleChannel::unsetMute(bool internal)
 /* -------------------------------------------------------------------------- */
 
 
+void SampleChannel::setBoost(float v)
+{
+	if (v > G_MAX_BOOST_DB)
+		boost = G_MAX_BOOST_DB;
+	else 
+	if (v < 0.0f)
+		boost = 0.0f;
+	else
+		boost = v;
+}
+
+
+float SampleChannel::getBoost()
+{
+	return boost;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 void SampleChannel::calcFadeoutStep()
 {
-	if (end - tracker < (1 / DEFAULT_FADEOUT_STEP) * 2)
+	if (end - tracker < (1 / G_DEFAULT_FADEOUT_STEP) * 2)
 		fadeoutStep = ceil((end - tracker) / volume) * 2; /// or volume_i ???
 	else
-		fadeoutStep = DEFAULT_FADEOUT_STEP;
+		fadeoutStep = G_DEFAULT_FADEOUT_STEP;
 }
 
 
@@ -689,9 +740,14 @@ void SampleChannel::empty()
 	status = STATUS_OFF;
 	if (wave) {
 		delete wave;
-		wave = NULL;
+		wave = nullptr;
 	}
-	status = STATUS_EMPTY;
+  begin   = 0;
+  end     = 0;
+  tracker = 0;
+	status  = STATUS_EMPTY;
+  volume  = G_DEFAULT_VOL;
+  boost   = G_DEFAULT_BOOST;
 	sendMidiLplay();
 }
 
@@ -736,22 +792,22 @@ bool SampleChannel::allocEmpty(int frames, int samplerate, int takeId)
 
 void SampleChannel::process(float *outBuffer, float *inBuffer)
 {
-	/* If armed and inbuffer is not null (i.e. input device available), copy input
-	buffer to vChan: this enables the live recording mode. The vChan will be
-	overwritten later by PluginHost::processStack, so that you would record "clean"
-	audio (i.e. not plugin-processed). */
+	/* If armed and inbuffer is not nullptr (i.e. input device available) and
+  input monitor is on, copy input buffer to vChan: this enables the input
+  monitoring. The vChan will be overwritten later by pluginHost::processStack,
+  so that you would record "clean" audio (i.e. not plugin-processed). */
 
-	if (armed && inBuffer)
+	if (armed && inBuffer && inputMonitor)
     for (int i=0; i<bufferSize; i++)
       vChan[i] += inBuffer[i]; // add, don't overwrite (no raw memcpy)
 
 #ifdef WITH_VST
-	pluginHost->processStack(vChan, PluginHost::CHANNEL, this);
+	pluginHost::processStack(vChan, pluginHost::CHANNEL, this);
 #endif
 
-	for (int j=0; j<bufferSize; j+=2) {
-		outBuffer[j]   += vChan[j]   * volume * panLeft  * boost;
-		outBuffer[j+1] += vChan[j+1] * volume * panRight * boost;
+  for (int j=0; j<bufferSize; j+=2) {
+		outBuffer[j]   += vChan[j]   * volume * calcPanning(0) * boost;
+		outBuffer[j+1] += vChan[j+1] * volume * calcPanning(1) * boost;
 	}
 }
 
@@ -761,7 +817,7 @@ void SampleChannel::process(float *outBuffer, float *inBuffer)
 
 void SampleChannel::kill(int frame)
 {
-	if (wave != NULL && status != STATUS_OFF) {
+	if (wave != nullptr && status != STATUS_OFF) {
 		if (mute || mute_i || (status == STATUS_WAIT && mode & LOOP_ANY))
 			hardStop(frame);
 		else
@@ -870,64 +926,15 @@ int SampleChannel::load(const char *file, int samplerate, int rsmpQuality)
 /* -------------------------------------------------------------------------- */
 
 
-int SampleChannel::readPatch_DEPR_(const char *f, int i, Patch_DEPR_ *patch,
-		int samplerate, int rsmpQuality)
-{
-	int res = load(f, samplerate, rsmpQuality);
-
-		volume      = patch->getVol(i);
-		key         = patch->getKey(i);
-		index       = patch->getIndex(i);
-		mode        = patch->getMode(i);
-		mute        = patch->getMute(i);
-		mute_s      = patch->getMute_s(i);
-		solo        = patch->getSolo(i);
-		boost       = patch->getBoost(i);
-		panLeft     = patch->getPanLeft(i);
-		panRight    = patch->getPanRight(i);
-		readActions = patch->getRecActive(i);
-		recStatus   = readActions ? REC_READING : REC_STOPPED;
-
-		readPatchMidiIn_DEPR_(i, *patch);
-		midiInReadActions = patch->getMidiValue(i, "InReadActions");
-		midiInPitch       = patch->getMidiValue(i, "InPitch");
-		readPatchMidiOut_DEPR_(i, *patch);
-
-	if (res == SAMPLE_LOADED_OK) {
-		setBegin(patch->getBegin(i));
-		setEnd  (patch->getEnd(i, wave->size));
-		setPitch(patch->getPitch(i));
-	}
-	else {
-		// volume = DEFAULT_VOL;
-		// mode   = DEFAULT_CHANMODE;
-		// status = STATUS_WRONG;
-		// key    = 0;
-
-		if (res == SAMPLE_LEFT_EMPTY)
-			status = STATUS_EMPTY;
-		else
-		if (res == SAMPLE_READ_ERROR)
-			status = STATUS_MISSING;
-		sendMidiLplay();
-	}
-
-	return res;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-int SampleChannel::readPatch(const string &basePath, int i, Patch *patch,
+int SampleChannel::readPatch(const string &basePath, int i,
 		pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality)
 {
 	/* load channel's data first: if the sample is missing or wrong, the channel
 	 * is not completely blank. */
 
-	Channel::readPatch("", i, patch, pluginMutex, samplerate, rsmpQuality);
+	Channel::readPatch("", i, pluginMutex, samplerate, rsmpQuality);
 
-	Patch::channel_t *pch = &patch->channels.at(i);
+	patch::channel_t *pch = &patch::channels.at(i);
 
 	mode              = pch->mode;
 	boost             = pch->boost;
@@ -935,6 +942,7 @@ int SampleChannel::readPatch(const string &basePath, int i, Patch *patch,
 	recStatus         = readActions ? REC_READING : REC_STOPPED;
 	midiInReadActions = pch->midiInReadActions;
 	midiInPitch       = pch->midiInPitch;
+  inputMonitor      = pch->inputMonitor;
 
 	int res = load((basePath + pch->samplePath).c_str(), samplerate, rsmpQuality);
 	if (res == SAMPLE_LOADED_OK) {
@@ -960,7 +968,7 @@ int SampleChannel::readPatch(const string &basePath, int i, Patch *patch,
 
 bool SampleChannel::canInputRec()
 {
-	return wave == NULL && armed;
+	return wave == nullptr && armed;
 }
 
 
@@ -1042,14 +1050,14 @@ void SampleChannel::start(int frame, bool doQuantize, int quantize,
 /* -------------------------------------------------------------------------- */
 
 
-int SampleChannel::writePatch(int i, bool isProject, Patch *patch)
+int SampleChannel::writePatch(int i, bool isProject)
 {
 	// TODO - this code belongs to an upper level (glue)
 
-	int pchIndex = Channel::writePatch(i, isProject, patch);
-	Patch::channel_t *pch = &patch->channels.at(pchIndex);
+	int pchIndex = Channel::writePatch(i, isProject);
+	patch::channel_t *pch = &patch::channels.at(pchIndex);
 
-	if (wave != NULL) {
+	if (wave != nullptr) {
 		pch->samplePath = wave->pathfile;
 		if (isProject)
 			pch->samplePath = gu_basename(wave->pathfile);  // make it portable
@@ -1063,6 +1071,7 @@ int SampleChannel::writePatch(int i, bool isProject, Patch *patch)
 	pch->boost             = boost;
 	pch->recActive         = readActions;
 	pch->pitch             = pitch;
+	pch->inputMonitor      = inputMonitor;
 	pch->midiInReadActions = midiInReadActions;
 	pch->midiInPitch       = midiInPitch;
 
