@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * sampleChannel
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,14 +25,18 @@
  * -------------------------------------------------------------------------- */
 
 
-#ifndef SAMPLE_CHANNEL_H
-#define SAMPLE_CHANNEL_H
+#ifndef G_SAMPLE_CHANNEL_H
+#define G_SAMPLE_CHANNEL_H
 
 
 #include <samplerate.h>
 #include "channel.h"
 
 
+class Patch;
+class Wave;
+
+
 class SampleChannel : public Channel
 {
 private:
@@ -46,15 +48,18 @@ private:
 	SRC_DATA   rsmp_data;
 
 	/* pChan
-	 * extra virtual channel for processing resampled data.  */
+	Extra virtual channel for processing resampled data. */
 
 	float *pChan;
 
 	/* frameRewind
-	 * exact frame in which a rewind occurs */
+	Exact frame in which a rewind occurs. */
 
 	int frameRewind;
 
+	float boost;
+	float pitch;
+
 	/* fillChan
 	 * copy from wave to *dest and resample data from wave, if necessary.
 	 * Start to fill pChan from byte 'offset'. If rewind=false don't
@@ -86,7 +91,7 @@ private:
 
 public:
 
-	SampleChannel(int bufferSize, class MidiMapConf *midiMapConf);
+	SampleChannel(int bufferSize, bool inputMonitor);
 	~SampleChannel();
 
 	void copy(const Channel *src, pthread_mutex_t *pluginMutex) override;
@@ -101,15 +106,13 @@ public:
 	void rewind() override;
 	void setMute(bool internal) override;
 	void unsetMute(bool internal) override;
-	int readPatch_DEPR_(const char *file, int i, class Patch_DEPR_ *patch,
-			int samplerate, int rsmpQuality) override;
-  int readPatch(const string &basePath, int i, class Patch *patch,
-			pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality) override;
-	int writePatch(int i, bool isProject, class Patch *patch) override;
-	void quantize(int index, int localFrame, class Mixer *m) override;
+  int readPatch(const std::string &basePath, int i, pthread_mutex_t *pluginMutex,
+    int samplerate, int rsmpQuality) override;
+	int writePatch(int i, bool isProject) override;
+	void quantize(int index, int localFrame) override;
 	void onZero(int frame, bool recsStopOnChanHalt) override;
 	void onBar(int frame) override;
-	void parseAction(Recorder::action *a, int localFrame, int globalFrame,
+	void parseAction(giada::m::recorder::action *a, int localFrame, int globalFrame,
 			int quantize, bool mixerIsRunning) override;
 	bool canInputRec() override;
 
@@ -128,7 +131,7 @@ public:
 	/* pushWave
 	 * add a new wave to an existing channel. */
 
-	void pushWave(class Wave *w);
+	void pushWave(Wave *w);
 
 	/* getPosition
 	 * returns the position of an active sample. If EMPTY o MISSING
@@ -146,12 +149,13 @@ public:
 	 * updates the pitch value and chanStart+chanEnd accordingly. */
 
 	void setPitch(float v);
+	float getPitch();
 
 	/* setStart/end
 	 * change begin/end read points in sample. */
 
-	void setBegin(unsigned v);
-	void setEnd  (unsigned v);
+	void setBegin(int v);
+	void setEnd  (int v);
 
 	/* save
 	 * save sample to file. */
@@ -174,14 +178,15 @@ public:
 
 	void setReadActions(bool v, bool recsStopOnChanHalt);
 
+	void setBoost(float v);
+	float getBoost();	
+
 	/* ------------------------------------------------------------------------ */
 
-	class  Wave *wave;
+	Wave  *wave;
 	int    tracker;         // chan position
 	int    begin;
 	int    end;
-  float  pitch;
-	float  boost;
 	int    mode;            // mode: see const.h
 	bool   qWait;           // quantizer wait
 	bool   fadeinOn;
@@ -192,6 +197,7 @@ public:
 	float  fadeoutStep;     // fadeout decrease
   int    fadeoutType;     // xfade or fadeout
   int		 fadeoutEnd;      // what to do when fadeout ends
+  bool   inputMonitor;
 
 	/* midi stuff */
 
