@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,11 +27,12 @@
  * -------------------------------------------------------------------------- */
 
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>  // memcpy
-#include <math.h>
-#include "../utils/utils.h"
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>  // memcpy
+#include <cmath>
+#include <samplerate.h>
+#include "../utils/fs.h"
 #include "../utils/log.h"
 #include "init.h"
 #include "const.h"
@@ -42,7 +43,7 @@ using std::string;
 
 
 Wave::Wave()
-: data     (NULL),
+: data     (nullptr),
 	size     (0),
 	isLogical(0),
 	isEdited (0) {}
@@ -61,7 +62,7 @@ Wave::~Wave()
 
 
 Wave::Wave(const Wave &other)
-: data     (NULL),
+: data     (nullptr),
 	size     (0),
 	isLogical(false),
 	isEdited (false)
@@ -81,11 +82,11 @@ Wave::Wave(const Wave &other)
 int Wave::open(const char *f)
 {
 	pathfile = f;
-	name     = gStripExt(gBasename(f).c_str());
+	name     = gu_stripExt(gu_basename(f));
 	fileIn   = sf_open(f, SFM_READ, &inHeader);
 
-	if (fileIn == NULL) {
-		gLog("[wave] unable to read %s. %s\n", f, sf_strerror(fileIn));
+	if (fileIn == nullptr) {
+		gu_log("[wave] unable to read %s. %s\n", f, sf_strerror(fileIn));
 		pathfile = "";
 		name     = "";
 		return 0;
@@ -118,13 +119,13 @@ int Wave::readData()
 {
 	size = inHeader.frames * inHeader.channels;
 	data = (float *) malloc(size * sizeof(float));
-	if (data == NULL) {
-		gLog("[wave] unable to allocate memory\n");
+	if (data == nullptr) {
+		gu_log("[wave] unable to allocate memory\n");
 		return 0;
 	}
 
 	if (sf_read_float(fileIn, data, size) != size)
-		gLog("[wave] warning: incomplete read!\n");
+		gu_log("[wave] warning: incomplete read!\n");
 
 	sf_close(fileIn);
 	return 1;
@@ -143,14 +144,14 @@ int Wave::writeData(const char *f)
 	outHeader.format     = inHeader.format;
 
 	fileOut = sf_open(f, SFM_WRITE, &outHeader);
-	if (fileOut == NULL) {
-		gLog("[wave] unable to open %s for exporting\n", f);
+	if (fileOut == nullptr) {
+		gu_log("[wave] unable to open %s for exporting\n", f);
 		return 0;
 	}
 
 	int out = sf_write_float(fileOut, data, size);
 	if (out != (int) size) {
-		gLog("[wave] error while exporting %s! %s\n", f, sf_strerror(fileOut));
+		gu_log("[wave] error while exporting %s! %s\n", f, sf_strerror(fileOut));
 		return 0;
 	}
 
@@ -166,9 +167,9 @@ int Wave::writeData(const char *f)
 
 void Wave::clear()
 {
-	if (data != NULL) {
+	if (data != nullptr) {
 		free(data);
-		data     = NULL;
+		data     = nullptr;
 		pathfile = "";
 		size     = 0;
 	}
@@ -185,8 +186,8 @@ int Wave::allocEmpty(unsigned __size, unsigned samplerate)
 	/// FIXME - this way if malloc fails size becomes wrong
 	size = __size;
 	data = (float *) malloc(size * sizeof(float));
-	if (data == NULL) {
-		gLog("[wave] unable to allocate memory\n");
+	if (data == nullptr) {
+		gu_log("[wave] unable to allocate memory\n");
 		return 0;
 	}
 
@@ -213,7 +214,7 @@ int Wave::resample(int quality, int newRate)
 
 	float *tmp = (float *) malloc(newSize * sizeof(float));
 	if (!tmp) {
-		gLog("[wave] unable to allocate memory for resampling\n");
+		gu_log("[wave] unable to allocate memory for resampling\n");
 		return -1;
 	}
 
@@ -224,11 +225,11 @@ int Wave::resample(int quality, int newRate)
 	src_data.output_frames = newSize/2;  // in frames, i.e. /2 (stereo)
 	src_data.src_ratio     = ratio;
 
-	gLog("[wave] resampling: new size=%d (%d frames)\n", newSize, newSize/2);
+	gu_log("[wave] resampling: new size=%d (%d frames)\n", newSize, newSize/2);
 
 	int ret = src_simple(&src_data, quality, 2);
 	if (ret != 0) {
-		gLog("[wave] resampling error: %s\n", src_strerror(ret));
+		gu_log("[wave] resampling error: %s\n", src_strerror(ret));
 		return 0;
 	}
 
@@ -245,12 +246,12 @@ int Wave::resample(int quality, int newRate)
 
 string Wave::basename(bool ext) const
 {
-	return ext ? gBasename(pathfile) : gStripExt(gBasename(pathfile));
+	return ext ? gu_basename(pathfile) : gu_stripExt(gu_basename(pathfile));
 }
 
 string Wave::extension() const
 {
-	return gGetExt(pathfile.c_str());
+	return gu_getExt(pathfile);
 }
 
 
@@ -259,11 +260,27 @@ string Wave::extension() const
 
 void Wave::updateName(const char *n)
 {
-	string ext = gGetExt(pathfile.c_str());
-	name       = gStripExt(gBasename(n).c_str());
-	pathfile   = gDirname(pathfile.c_str()) + G_SLASH + name + "." + ext;
+	string ext = gu_getExt(pathfile);
+	name       = gu_stripExt(gu_basename(n));
+	pathfile   = gu_dirname(pathfile) + G_SLASH + name + "." + ext;
 	isLogical  = true;
 
 	/* a wave with updated name must become logical, since the underlying
 	 * file does not exist yet. */
 }
+
+
+/* -------------------------------------------------------------------------- */
+
+
+int  Wave::rate    () { return inHeader.samplerate; }
+int  Wave::channels() { return inHeader.channels; }
+int  Wave::frames  () { return inHeader.frames; }
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Wave::rate    (int v) { inHeader.samplerate = v; }
+void Wave::channels(int v) { inHeader.channels = v; }
+void Wave::frames  (int v) { inHeader.frames = v; }
