@@ -7,7 +7,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -28,8 +28,8 @@
  * -------------------------------------------------------------------------- */
 
 
-#ifndef __GLUE_PLUGIN_H__
-#define __GLUE_PLUGIN_H__
+#ifndef G_GLUE_PLUGIN_H
+#define G_GLUE_PLUGIN_H
 
 
 #ifdef WITH_VST
