@@ -2,12 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * glue
- * Intermediate layer GUI <-> CORE.
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -35,44 +32,40 @@
 #include "../core/plugin.h"
 #include "../core/conf.h"
 #include "../core/patch.h"
-#include "../core/patch_DEPR_.h" // TODO - remove, used only for DEPR calls
 #include "../core/sampleChannel.h"
 #include "../core/midiChannel.h"
+#include "../core/clock.h"
 #include "../core/wave.h"
 #include "../utils/gui.h"
 #include "../utils/log.h"
+#include "../utils/fs.h"
+#include "../gui/elems/basics/progress.h"
 #include "../gui/elems/mainWindow/keyboard/column.h"
 #include "../gui/elems/mainWindow/keyboard/keyboard.h"
 #include "../gui/dialogs/gd_mainWindow.h"
 #include "../gui/dialogs/gd_warnings.h"
-#include "../gui/dialogs/gd_browser.h"
-#include "main.h" // TODO - remove, used only for DEPR calls
+#include "../gui/dialogs/browser/browserSave.h"
+#include "../gui/dialogs/browser/browserLoad.h"
+#include "main.h"
 #include "channel.h"
 #include "storage.h"
 
 
+extern gdMainWindow *G_MainWin;
+
+
 using std::string;
 using std::vector;
-
-
-extern gdMainWindow *G_MainWin;
-extern Mixer	   		 G_Mixer;
-extern Recorder			 G_Recorder;
-extern Patch         G_Patch;
-extern Conf          G_Conf;
-extern Patch_DEPR_   G_Patch_DEPR_; // TODO - remove, used only for DEPR calls
-#ifdef WITH_VST
-extern PluginHost    G_PluginHost;
-#endif
+using namespace giada::m;
 
 
 #ifdef WITH_VST
 
-static void __glue_fillPatchGlobalsPlugins__(vector <Plugin *> *host, vector<Patch::plugin_t> *patch)
+static void __glue_fillPatchGlobalsPlugins__(vector <Plugin *> *host, vector<patch::plugin_t> *patch)
 {
 	for (unsigned i=0; i<host->size(); i++) {
 		Plugin *pl = host->at(i);
-		Patch::plugin_t ppl;
+		patch::plugin_t ppl;
 		ppl.path = pl->getUniqueId();
 		ppl.bypass = pl->isBypassed();
 		int numParams = pl->getNumParameters();
@@ -92,20 +85,20 @@ static void __glue_fillPatchColumns__()
 {
 	for (unsigned i=0; i<G_MainWin->keyboard->getTotalColumns(); i++) {
 		geColumn *gCol = G_MainWin->keyboard->getColumn(i);
-		Patch::column_t pCol;
+		patch::column_t pCol;
 		pCol.index = gCol->getIndex();
 		pCol.width = gCol->w();
 		for (int k=0; k<gCol->countChannels(); k++) {
 			Channel *colChannel = gCol->getChannel(k);
-			for (unsigned j=0; j<G_Mixer.channels.size(); j++) {
-				Channel *mixerChannel = G_Mixer.channels.at(j);
+			for (unsigned j=0; j<mixer::channels.size(); j++) {
+				Channel *mixerChannel = mixer::channels.at(j);
 				if (colChannel == mixerChannel) {
 					pCol.channels.push_back(mixerChannel->index);
 					break;
 				}
 			}
 		}
-		G_Patch.columns.push_back(pCol);
+		patch::columns.push_back(pCol);
 	}
 }
 
@@ -115,8 +108,8 @@ static void __glue_fillPatchColumns__()
 
 static void __glue_fillPatchChannels__(bool isProject)
 {
-	for (unsigned i=0; i<G_Mixer.channels.size(); i++) {
-		G_Mixer.channels.at(i)->writePatch(i, isProject, &G_Patch);
+	for (unsigned i=0; i<mixer::channels.size(); i++) {
+		mixer::channels.at(i)->writePatch(i, isProject);
 	}
 }
 
@@ -126,25 +119,25 @@ static void __glue_fillPatchChannels__(bool isProject)
 
 static void __glue_fillPatchGlobals__(const string &name)
 {
-	G_Patch.version      = G_VERSION_STR;
-	G_Patch.versionMajor = G_VERSION_MAJOR;
-	G_Patch.versionMinor = G_VERSION_MINOR;
-	G_Patch.versionPatch = G_VERSION_PATCH;
-	G_Patch.name         = name;
-	G_Patch.bpm          = G_Mixer.bpm;
-	G_Patch.bars         = G_Mixer.bars;
-	G_Patch.beats        = G_Mixer.beats;
-	G_Patch.quantize     = G_Mixer.quantize;
-	G_Patch.masterVolIn  = G_Mixer.inVol;
-  G_Patch.masterVolOut = G_Mixer.outVol;
-  G_Patch.metronome    = G_Mixer.metronome;
+	patch::version      = G_VERSION_STR;
+	patch::versionMajor = G_VERSION_MAJOR;
+	patch::versionMinor = G_VERSION_MINOR;
+	patch::versionPatch = G_VERSION_PATCH;
+	patch::name         = name;
+	patch::bpm          = clock::getBpm();
+	patch::bars         = clock::getBars();
+	patch::beats        = clock::getBeats();
+	patch::quantize     = clock::getQuantize();
+	patch::masterVolIn  = mixer::inVol;
+  patch::masterVolOut = mixer::outVol;
+  patch::metronome    = mixer::metronome;
 
 #ifdef WITH_VST
 
-	__glue_fillPatchGlobalsPlugins__(G_PluginHost.getStack(PluginHost::MASTER_IN),
-			&G_Patch.masterInPlugins);
-	__glue_fillPatchGlobalsPlugins__(G_PluginHost.getStack(PluginHost::MASTER_OUT),
-			&G_Patch.masterOutPlugins);
+	__glue_fillPatchGlobalsPlugins__(pluginHost::getStack(pluginHost::MASTER_IN),
+			&patch::masterInPlugins);
+	__glue_fillPatchGlobalsPlugins__(pluginHost::getStack(pluginHost::MASTER_OUT),
+			&patch::masterOutPlugins);
 
 #endif
 }
@@ -156,13 +149,13 @@ static void __glue_fillPatchGlobals__(const string &name)
 static bool __glue_savePatch__(const string &fullPath, const string &name,
 		bool isProject)
 {
-	G_Patch.init();
+	patch::init();
 
 	__glue_fillPatchGlobals__(name);
 	__glue_fillPatchChannels__(isProject);
 	__glue_fillPatchColumns__();
 
-	if (G_Patch.write(fullPath)) {
+	if (patch::write(fullPath)) {
 		gu_updateMainWinLabel(name);
 		gu_log("[glue_savePatch] patch saved as %s\n", fullPath.c_str());
 		return true;
@@ -176,7 +169,7 @@ static bool __glue_savePatch__(const string &fullPath, const string &name,
 
 void glue_savePatch(void *data)
 {
-	gdSaveBrowser *browser = (gdSaveBrowser*) data;
+	gdBrowserSave *browser = (gdBrowserSave*) data;
 	string name            = browser->getName();
 	string fullPath        = browser->getCurrentPath() + G_SLASH + gu_stripExt(name) + ".gptc";
 
@@ -190,7 +183,7 @@ void glue_savePatch(void *data)
 			return;
 
 	if (__glue_savePatch__(fullPath, name, false)) {  // false == not a project
-		G_Conf.patchPath = gu_dirname(fullPath);
+		conf::patchPath = gu_dirname(fullPath);
 		browser->do_callback();
 	}
 	else
@@ -203,7 +196,7 @@ void glue_savePatch(void *data)
 
 void glue_loadPatch(void *data)
 {
-	gdLoadBrowser *browser = (gdLoadBrowser*) data;
+	gdBrowserLoad *browser = (gdBrowserLoad*) data;
 	string fullPath        = browser->getSelectedItem();
 	bool isProject         = gu_isProject(browser->getSelectedItem());
 
@@ -218,34 +211,16 @@ void glue_loadPatch(void *data)
 		basePath   = fullPath + G_SLASH;
 	}
 
-	/* try to load the new JSON-based patch. If it fails, fall back to deprecated
-	* one. */
-
-	int  res = G_Patch.read(fileToLoad);
-	bool deprecated = false;
-
-	if (res == PATCH_UNREADABLE) {
-		gu_log("[glue] failed reading JSON-based patch. Trying with the deprecated method\n");
-		deprecated = true;
-		res = glue_loadPatch__DEPR__(gu_basename(fileToLoad).c_str(), fileToLoad.c_str(),
-				browser->getStatusBar(), isProject);
-	}
-
+	int res = patch::read(fileToLoad);
 	if (res != PATCH_READ_OK) {
 		if (res == PATCH_UNREADABLE)
 			isProject ? gdAlert("This project is unreadable.") : gdAlert("This patch is unreadable.");
 		else
 		if (res == PATCH_INVALID)
 			isProject ? gdAlert("This project is not valid.") : gdAlert("This patch is not valid.");
-
 		browser->hideStatusBar();
 		return;
 	}
-	else
-	if (deprecated) {
-		browser->do_callback();
-		return;
-	}
 
 	/* close all other windows. This prevents segfault if plugin
 	 * windows GUIs are on. */
@@ -263,40 +238,39 @@ void glue_loadPatch(void *data)
 	/* Add common stuff, columns and channels. Also increment the progress bar
 	 * by 0.8 / total_channels steps.  */
 
-	float steps = 0.8 / G_Patch.channels.size();
-	for (unsigned i=0; i<G_Patch.columns.size(); i++) {
-		Patch::column_t *col = &G_Patch.columns.at(i);
+	float steps = 0.8 / patch::channels.size();
+	for (unsigned i=0; i<patch::columns.size(); i++) {
+		patch::column_t *col = &patch::columns.at(i);
 		G_MainWin->keyboard->addColumn(col->width);
-		for (unsigned k=0; k<G_Patch.channels.size(); k++) {
-			if (G_Patch.channels.at(k).column == col->index) {
-				Channel *ch = glue_addChannel(G_Patch.channels.at(k).column,
-						G_Patch.channels.at(k).type);
-				ch->readPatch(basePath, k, &G_Patch, &G_Mixer.mutex_plugins,
-						G_Conf.samplerate, G_Conf.rsmpQuality);
+		for (unsigned k=0; k<patch::channels.size(); k++) {
+			if (patch::channels.at(k).column == col->index) {
+				Channel *ch = glue_addChannel(patch::channels.at(k).column,
+					patch::channels.at(k).type);
+				ch->readPatch(basePath, k, &mixer::mutex_plugins, conf::samplerate,
+          conf::rsmpQuality);
 			}
-			//__glue_setProgressBar__(status, steps);
 			browser->setStatusBar(steps);
 		}
 	}
 
 	/* fill Mixer */
 
-	mh_readPatch();
+	mh::readPatch();
 
 	/* let recorder recompute the actions' positions if the current
 	 * samplerate != patch samplerate */
 
-	G_Recorder.updateSamplerate(G_Conf.samplerate, G_Patch.samplerate);
+	recorder::updateSamplerate(conf::samplerate, patch::samplerate);
 
 	/* save patchPath by taking the last dir of the broswer, in order to
 	 * reuse it the next time */
 
-	G_Conf.patchPath = gu_dirname(fullPath);
+	conf::patchPath = gu_dirname(fullPath);
 
 	/* refresh GUI */
 
 	gu_updateControls();
-	gu_updateMainWinLabel(G_Patch.name);
+	gu_updateMainWinLabel(patch::name);
 
 	browser->setStatusBar(0.1f);
 	//__glue_setProgressBar__(status, 1.0f);
@@ -305,7 +279,7 @@ void glue_loadPatch(void *data)
 
 #ifdef WITH_VST
 
-	if (G_PluginHost.hasMissingPlugins())
+	if (pluginHost::hasMissingPlugins())
 		gdAlert("Some plugins were not loaded successfully.\nCheck the plugin browser to know more.");
 
 #endif
@@ -317,98 +291,9 @@ void glue_loadPatch(void *data)
 /* -------------------------------------------------------------------------- */
 
 
-int glue_loadPatch__DEPR__(const char *fname, const char *fpath, gProgress *status, bool isProject)
-{
-	/* update browser's status bar with % 0.1 */
-
-	status->show();
-	status->value(0.1f);
-	//Fl::check();
-	Fl::wait(0);
-
-	/* is it a valid patch? */
-
-	int res = G_Patch_DEPR_.open(fpath);
-	if (res != PATCH_READ_OK)
-		return res;
-
-	/* close all other windows. This prevents segfault if plugin windows
-	 * GUI are on. */
-
-	if (res)
-		gu_closeAllSubwindows();
-
-	/* reset the system. False(1): don't update the gui right now. False(2): do
-	 * not create empty columns. */
-
-	glue_resetToInitState(false, false);
-
-	status->value(0.2f);  // progress status: % 0.2
-	//Fl::check();
-	Fl::wait(0);
-
-	/* mixerHandler will update the samples inside Mixer */
-
-	mh_loadPatch_DEPR_(isProject, gu_dirname(fpath).c_str());
-
-	/* take the patch name and update the main window's title */
-
-	G_Patch_DEPR_.getName();
-	gu_updateMainWinLabel(G_Patch_DEPR_.name);
-
-	status->value(0.4f);  // progress status: 0.4
-	//Fl::check();
-	Fl::wait(0);
-
-	G_Patch_DEPR_.readRecs();
-	status->value(0.6f);  // progress status: 0.6
-	//Fl::check();
-	Fl::wait(0);
-
-#ifdef WITH_VST
-	int resPlugins = G_Patch_DEPR_.readPlugins();
-	status->value(0.8f);  // progress status: 0.8
-	//Fl::check();
-	Fl::wait(0);
-#endif
-
-	/* this one is vital: let recorder recompute the actions' positions if
-	 * the current samplerate != patch samplerate */
-
-	G_Recorder.updateSamplerate(G_Conf.samplerate, G_Patch_DEPR_.samplerate);
-
-	/* update gui */
-
-	gu_updateControls();
-
-	status->value(1.0f);  // progress status: 1.0 (done)
-	//Fl::check();
-	Fl::wait(0);
-
-	/* save patchPath by taking the last dir of the broswer, in order to
-	 * reuse it the next time */
-
-	G_Conf.patchPath = gu_dirname(fpath).c_str();
-
-	gu_log("[glue] patch %s loaded\n", fname);
-
-#ifdef WITH_VST
-	if (resPlugins != 1)
-		gdAlert("Some VST plugins were not loaded successfully.");
-#endif
-
-	gdAlert("This patch is using a deprecated format.\nPlease save it again to store it properly.");
-
-	return res;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 void glue_saveProject(void *data)
 {
-	gdSaveBrowser *browser = (gdSaveBrowser*) data;
+	gdBrowserSave *browser = (gdBrowserSave*) data;
 	string name            = browser->getName();
 	string folderPath      = browser->getCurrentPath(); //browser->getSelectedItem();
 	string fullPath        = folderPath + G_SLASH + gu_stripExt(name) + ".gprj";
@@ -431,14 +316,14 @@ void glue_saveProject(void *data)
 	/* copy all samples inside the folder. Takes and logical ones are saved
 	 * via glue_saveSample() */
 
-	for (unsigned i=0; i<G_Mixer.channels.size(); i++) {
+	for (unsigned i=0; i<mixer::channels.size(); i++) {
 
-		if (G_Mixer.channels.at(i)->type == CHANNEL_MIDI)
+		if (mixer::channels.at(i)->type == CHANNEL_MIDI)
 			continue;
 
-		SampleChannel *ch = (SampleChannel*) G_Mixer.channels.at(i);
+		SampleChannel *ch = (SampleChannel*) mixer::channels.at(i);
 
-		if (ch->wave == NULL)
+		if (ch->wave == nullptr)
 			continue;
 
 		/* update the new samplePath: everything now comes from the project
@@ -465,7 +350,7 @@ void glue_saveProject(void *data)
 
 void glue_loadSample(void *data)
 {
-	gdLoadBrowser *browser = (gdLoadBrowser*) data;
+	gdBrowserLoad *browser = (gdBrowserLoad*) data;
 	string fullPath        = browser->getSelectedItem();
 
 	if (fullPath.empty())
@@ -474,7 +359,7 @@ void glue_loadSample(void *data)
 	int res = glue_loadChannel((SampleChannel*) browser->getChannel(), fullPath.c_str());
 
 	if (res == SAMPLE_LOADED_OK) {
-		G_Conf.samplePath = gu_dirname(fullPath);
+		conf::samplePath = gu_dirname(fullPath);
 		browser->do_callback();
 		G_MainWin->delSubWindow(WID_SAMPLE_EDITOR); // if editor is open
 	}
@@ -488,9 +373,9 @@ void glue_loadSample(void *data)
 
 void glue_saveSample(void *data)
 {
-	gdSaveBrowser *browser = (gdSaveBrowser*) data;
+	gdBrowserSave *browser = (gdBrowserSave*) data;
 	string name            = browser->getName();
-	string folderPath      = browser->getSelectedItem();
+	string folderPath      = browser->getCurrentPath();
 
 	if (name == "") {
 		gdAlert("Please choose a file name.");
@@ -505,8 +390,9 @@ void glue_saveSample(void *data)
 		if (!gdConfirmWin("Warning", "File exists: overwrite?"))
 			return;
 
-	if (((SampleChannel*)browser->getChannel())->save(filePath.c_str())) {
-		G_Conf.samplePath = gu_dirname(folderPath);
+	if (static_cast<SampleChannel*>(browser->getChannel())->save(filePath.c_str())) {
+    gu_log("[glue_saveSample] sample saved to %s\n", filePath.c_str());
+		conf::samplePath = gu_dirname(filePath);
 		browser->do_callback();
 	}
 	else
