@@ -2,12 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * glue
- * Intermediate layer GUI <-> CORE.
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -28,12 +25,11 @@
  * -------------------------------------------------------------------------- */
 
 
-#ifndef GLUE_STORAGE_H
-#define GLUE_STORAGE_H
+#ifndef G_GLUE_STORAGE_H
+#define G_GLUE_STORAGE_H
 
 
 void glue_loadPatch  (void *data);
-int glue_loadPatch__DEPR__(const char *fname, const char *fpath, class gProgress *status, bool isProject);
 void glue_savePatch  (void *data);
 void glue_saveProject(void *data);
 void glue_saveSample (void *data);
