@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * gd_about
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,45 +25,46 @@
  * -------------------------------------------------------------------------- */
 
 
+#include <FL/Fl_Pixmap.H>
+#include <FL/fl_draw.H>
 #include <jansson.h>
 #include "../../core/conf.h"
 #include "../../core/const.h"
-#include "../../core/kernelAudio.h"
-#include "../../core/kernelMidi.h"
 #include "../../core/graphics.h"
 #ifdef WITH_VST
   #include "../../deps/juce-config.h"
 #endif
 #include "../../utils/gui.h"
-#include "../elems/ge_mixed.h"
+#include "../../utils/deps.h"
+#include "../elems/basics/button.h"
+#include "../elems/basics/box.h"
 #include "gd_about.h"
 
 
-extern Conf        G_Conf;
-extern KernelAudio G_KernelAudio;
-extern KernelMidi  G_KernelMidi;
+using namespace giada::m;
+using namespace giada::u;
 
 
 gdAbout::gdAbout()
 #ifdef WITH_VST
-: gWindow(340, 435, "About Giada")
+: gdWindow(340, 435, "About Giada")
 {
 #else
-: gWindow(340, 350, "About Giada")
+: gdWindow(340, 350, "About Giada")
 {
 #endif
 
-	if (G_Conf.aboutX)
-		resize(G_Conf.aboutX, G_Conf.aboutY, w(), h());
+	if (conf::aboutX)
+		resize(conf::aboutX, conf::aboutY, w(), h());
 
 	set_modal();
 
-	logo  = new gBox(8, 10, 324, 86);
-	text  = new gBox(8, 120, 324, 145);
-	close = new gClick(252, h()-28, 80, 20, "Close");
+	logo  = new geBox(8, 10, 324, 86);
+	text  = new geBox(8, 120, 324, 145);
+	close = new geButton(252, h()-28, 80, 20, "Close");
 #ifdef WITH_VST
-	vstLogo = new gBox(8, 265, 324, 50);
-	vstText = new gBox(8, 315, 324, 46);
+	vstLogo = new geBox(8, 265, 324, 50);
+	vstText = new geBox(8, 315, 324, 46);
 #endif
 	end();
 
@@ -79,7 +78,7 @@ gdAbout::gdAbout()
 		"Developed by Monocasual\n"
 		"Based on FLTK (%d.%d.%d), RtAudio (%s),\n"
 		"RtMidi (%s), Libsamplerate, Jansson (%s),\n"
-		"Libsndfile"
+		"Libsndfile (%s)"
 #ifdef WITH_VST
 		", JUCE (%d.%d.%d)\n\n"
 #else
@@ -90,9 +89,9 @@ gdAbout::gdAbout()
 		"News, infos, contacts and documentation:\n"
 		"www.giadamusic.com",
 		FL_MAJOR_VERSION, FL_MINOR_VERSION, FL_PATCH_VERSION,
-		G_KernelAudio.getRtAudioVersion().c_str(),
-		G_KernelMidi.getRtMidiVersion().c_str(),
-		JANSSON_VERSION
+		deps::getRtAudioVersion().c_str(),
+		deps::getRtMidiVersion().c_str(),
+		JANSSON_VERSION, deps::getLibsndfileVersion().c_str()
 #ifdef WITH_VST
 		, JUCE_MAJOR_VERSION, JUCE_MINOR_VERSION, JUCE_BUILDNUMBER);
 #else
@@ -128,8 +127,8 @@ gdAbout::gdAbout()
 
 gdAbout::~gdAbout()
 {
-	G_Conf.aboutX = x();
-	G_Conf.aboutY = y();
+	conf::aboutX = x();
+	conf::aboutY = y();
 }
 
 
