@@ -1,12 +1,10 @@
-/* ---------------------------------------------------------------------
+/* -----------------------------------------------------------------------------
  *
  * Giada - Your Hardcore Loopmachine
  *
- * gd_beatsInput
+ * -----------------------------------------------------------------------------
  *
- * ---------------------------------------------------------------------
- *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,40 +22,44 @@
  * along with Giada - Your Hardcore Loopmachine. If not, see
  * <http://www.gnu.org/licenses/>.
  *
- * ------------------------------------------------------------------ */
+ * -------------------------------------------------------------------------- */
 
 
 #include "../../utils/gui.h"
 #include "../../core/mixer.h"
+#include "../../core/clock.h"
 #include "../../core/conf.h"
 #include "../../core/const.h"
 #include "../../glue/main.h"
-#include "../elems/ge_mixed.h"
+#include "../elems/basics/input.h"
+#include "../elems/basics/button.h"
+#include "../elems/basics/check.h"
 #include "gd_beatsInput.h"
 #include "gd_mainWindow.h"
 
 
-extern Mixer				 G_Mixer;
-extern Conf          G_Conf;
 extern gdMainWindow *mainWin;
 
 
+using namespace giada::m;
+
+
 gdBeatsInput::gdBeatsInput()
-	: gWindow(164, 60, "Beats")
+	: gdWindow(164, 60, "Beats")
 {
-	if (G_Conf.beatsX)
-		resize(G_Conf.beatsX, G_Conf.beatsY, w(), h());
+	if (conf::beatsX)
+		resize(conf::beatsX, conf::beatsY, w(), h());
 
 	set_modal();
 
-	beats     = new gInput(8,  8,  35, 20);
-	bars      = new gInput(47, 8,  35, 20);
-	ok 		    = new gClick(86, 8,  70, 20, "Ok");
-	resizeRec = new gCheck(8,  40, 12, 12, "resize recorded actions");
+	beats     = new geInput(8,  8,  35, 20);
+	bars      = new geInput(47, 8,  35, 20);
+	ok 		    = new geButton(86, 8,  70, 20, "Ok");
+	resizeRec = new geCheck(8,  40, 12, 12, "resize recorded actions");
 	end();
 
-	char buf_bars[3]; sprintf(buf_bars, "%d", G_Mixer.bars);
-	char buf_beats[3]; sprintf(buf_beats, "%d", G_Mixer.beats);
+	char buf_bars[3]; sprintf(buf_bars, "%d", clock::getBars());
+	char buf_beats[3]; sprintf(buf_beats, "%d", clock::getBeats());
 	beats->maximum_size(2);
 	beats->value(buf_beats);
 	beats->type(FL_INT_INPUT);
@@ -66,7 +68,7 @@ gdBeatsInput::gdBeatsInput()
 	bars->type(FL_INT_INPUT);
 	ok->shortcut(FL_Enter);
 	ok->callback(cb_update_batt, (void*)this);
-	resizeRec->value(G_Conf.resizeRecordings);
+	resizeRec->value(conf::resizeRecordings);
 
 	gu_setFavicon(this);
 	setId(WID_BEATS);
@@ -79,9 +81,9 @@ gdBeatsInput::gdBeatsInput()
 
 gdBeatsInput::~gdBeatsInput()
 {
-	G_Conf.beatsX = x();
-	G_Conf.beatsY = y();
-	G_Conf.resizeRecordings =	resizeRec->value();
+	conf::beatsX = x();
+	conf::beatsY = y();
+	conf::resizeRecordings =	resizeRec->value();
 }
 
 
