@@ -1,12 +1,10 @@
-/* ---------------------------------------------------------------------
+/* -----------------------------------------------------------------------------
  *
  * Giada - Your Hardcore Loopmachine
  *
- * gd_bpmInput
+ * -----------------------------------------------------------------------------
  *
- * ---------------------------------------------------------------------
- *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,39 +22,43 @@
  * along with Giada - Your Hardcore Loopmachine. If not, see
  * <http://www.gnu.org/licenses/>.
  *
- * ------------------------------------------------------------------ */
+ * -------------------------------------------------------------------------- */
 
 
+#include <cstring>
 #include "../../core/conf.h"
 #include "../../core/const.h"
 #include "../../core/mixer.h"
+#include "../../core/clock.h"
 #include "../../glue/main.h"
 #include "../../utils/gui.h"
-#include "../elems/ge_mixed.h"
+#include "../elems/basics/button.h"
+#include "../elems/basics/input.h"
 #include "gd_bpmInput.h"
 #include "gd_mainWindow.h"
 
 
-extern Mixer     		 G_Mixer;
-extern Conf          G_Conf;
 extern gdMainWindow *mainWin;
 
 
-gdBpmInput::gdBpmInput(const char *label)
-: gWindow(144, 36, "Bpm") {
+using namespace giada::m;
 
-	if (G_Conf.bpmX)
-		resize(G_Conf.bpmX, G_Conf.bpmY, w(), h());
+
+gdBpmInput::gdBpmInput(const char *label)
+: gdWindow(144, 36, "Bpm")
+{
+	if (conf::bpmX)
+		resize(conf::bpmX, conf::bpmY, w(), h());
 
 	set_modal();
 
-	input_a = new gInput(8,  8, 30, 20);
-	input_b = new gInput(42, 8, 20, 20);
-	ok 		  = new gClick(66, 8, 70, 20, "Ok");
+	input_a = new geInput(8,  8, 30, 20);
+	input_b = new geInput(42, 8, 20, 20);
+	ok 		  = new geButton(66, 8, 70, 20, "Ok");
 	end();
 
 	char   a[4];
-	snprintf(a, 4, "%d", (int) G_Mixer.bpm);
+	snprintf(a, 4, "%d", (int) clock::getBpm());
 	char   b[2];
 	for (unsigned i=0; i<strlen(label); i++)	// looking for the dot
 		if (label[i] == '.') {
@@ -80,25 +82,27 @@ gdBpmInput::gdBpmInput(const char *label)
 }
 
 
-/* ------------------------------------------------------------------ */
+/* -------------------------------------------------------------------------- */
 
 
-gdBpmInput::~gdBpmInput() {
-	G_Conf.bpmX = x();
-	G_Conf.bpmY = y();
+gdBpmInput::~gdBpmInput()
+{
+	conf::bpmX = x();
+	conf::bpmY = y();
 }
 
 
-/* ------------------------------------------------------------------ */
+/* -------------------------------------------------------------------------- */
 
 
 void gdBpmInput::cb_update_bpm(Fl_Widget *w, void *p) { ((gdBpmInput*)p)->__cb_update_bpm(); }
 
 
-/* ------------------------------------------------------------------ */
+/* -------------------------------------------------------------------------- */
 
 
-void gdBpmInput::__cb_update_bpm() {
+void gdBpmInput::__cb_update_bpm()
+{
 	if (strcmp(input_a->value(), "") == 0)
 		return;
 	glue_setBpm(input_a->value(), input_b->value());
