@@ -1,12 +1,10 @@
-/* ---------------------------------------------------------------------
+/* -----------------------------------------------------------------------------
  *
  * Giada - Your Hardcore Loopmachine
  *
- * gd_devInfo
+ * -----------------------------------------------------------------------------
  *
- * ---------------------------------------------------------------------
- *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,20 +22,21 @@
  * along with Giada - Your Hardcore Loopmachine. If not, see
  * <http://www.gnu.org/licenses/>.
  *
- * ------------------------------------------------------------------ */
+ * -------------------------------------------------------------------------- */
 
 
+#include <FL/fl_draw.H>
 #include "../../core/kernelAudio.h"
 #include "../../utils/gui.h"
 #include "../../utils/string.h"
-#include "../elems/ge_mixed.h"
+#include "../elems/basics/button.h"
+#include "../elems/basics/box.h"
+#include "window.h"
 #include "gd_devInfo.h"
 
 
-extern KernelAudio G_KernelAudio;
-
-
 using std::string;
+using namespace giada::m;
 
 
 gdDevInfo::gdDevInfo(unsigned dev)
@@ -45,21 +44,21 @@ gdDevInfo::gdDevInfo(unsigned dev)
 {
 	set_modal();
 
-	text  = new gBox(8, 8, 320, 200, "", (Fl_Align) (FL_ALIGN_LEFT | FL_ALIGN_TOP));
-	close = new gClick(252, h()-28, 80, 20, "Close");
+	text  = new geBox(8, 8, 320, 200, "", (Fl_Align) (FL_ALIGN_LEFT | FL_ALIGN_TOP));
+	close = new geButton(252, h()-28, 80, 20, "Close");
 	end();
 
 	string body  = "";
 	int    lines = 7;
 
-	body  = "Device name: " + G_KernelAudio.getDeviceName(dev) + "\n";
-	body += "Total output(s): " + gu_itoa(G_KernelAudio.getMaxOutChans(dev)) + "\n";
-	body += "Total intput(s): " + gu_itoa(G_KernelAudio.getMaxInChans(dev)) + "\n";
-	body += "Duplex channel(s): " + gu_itoa(G_KernelAudio.getDuplexChans(dev)) + "\n";
-	body += "Default output: " + string(G_KernelAudio.isDefaultOut(dev) ? "yes" : "no") + "\n";
-	body += "Default input: " + string(G_KernelAudio.isDefaultIn(dev) ? "yes" : "no") + "\n";
+	body  = "Device name: " + kernelAudio::getDeviceName(dev) + "\n";
+	body += "Total output(s): " + gu_itoa(kernelAudio::getMaxOutChans(dev)) + "\n";
+	body += "Total intput(s): " + gu_itoa(kernelAudio::getMaxInChans(dev)) + "\n";
+	body += "Duplex channel(s): " + gu_itoa(kernelAudio::getDuplexChans(dev)) + "\n";
+	body += "Default output: " + string(kernelAudio::isDefaultOut(dev) ? "yes" : "no") + "\n";
+	body += "Default input: " + string(kernelAudio::isDefaultIn(dev) ? "yes" : "no") + "\n";
 
-	int totalFreq = G_KernelAudio.getTotalFreqs(dev);
+	int totalFreq = kernelAudio::getTotalFreqs(dev);
 	body += "Supported frequencies: " + gu_itoa(totalFreq);
 
 	for (int i=0; i<totalFreq; i++) {
@@ -67,7 +66,7 @@ gdDevInfo::gdDevInfo(unsigned dev)
 			body += "\n    ";  // add new line each 6 printed freqs AND on the first line (i % 0 != 0)
 			lines++;
 		}
-		body += gu_itoa( G_KernelAudio.getFreq(dev, i)) + "  ";
+		body += gu_itoa( kernelAudio::getFreq(dev, i)) + "  ";
 	}
 
 	text->copy_label(body.c_str());
