@@ -1,12 +1,10 @@
-/* ---------------------------------------------------------------------
+/* -----------------------------------------------------------------------------
  *
  * Giada - Your Hardcore Loopmachine
  *
- * gd_devInfo
+ * -----------------------------------------------------------------------------
  *
- * ---------------------------------------------------------------------
- *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,22 +22,29 @@
  * along with Giada - Your Hardcore Loopmachine. If not, see
  * <http://www.gnu.org/licenses/>.
  *
- * ------------------------------------------------------------------ */
+ * -------------------------------------------------------------------------- */
 
 
 #ifndef GD_DEV_INFO_H
 #define GD_DEV_INFO_H
 
-#include <FL/Fl.H>
+
 #include <FL/Fl_Window.H>
 
 
-class gdDevInfo : public Fl_Window {
+class geBox;
+class geButton;
+
+
+class gdDevInfo : public Fl_Window
+{
 private:
-	class gBox 	 *text;
-	class gClick *close;
+
+	geBox   	 *text;
+	geButton *close;
 
 public:
+
 	gdDevInfo(unsigned dev);
 	~gdDevInfo();
 };
