@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * gd_keyGrabber
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -33,7 +31,7 @@
 #include "../../core/sampleChannel.h"
 #include "../../core/midiChannel.h"
 #include "../../utils/log.h"
-#include "../elems/ge_mixed.h"
+#include "../elems/basics/box.h"
 #include "../elems/mainWindow/keyboard/keyboard.h"
 #include "../elems/mainWindow/keyboard/channel.h"
 #include "../elems/mainWindow/keyboard/channelButton.h"
@@ -42,17 +40,16 @@
 #include "gd_mainWindow.h"
 
 
-extern Conf	         G_Conf;
 extern gdMainWindow *mainWin;
 
 
 gdKeyGrabber::gdKeyGrabber(Channel *ch)
-	: gWindow(300, 126, "Key configuration"), ch(ch)
+	: gdWindow(300, 126, "Key configuration"), ch(ch)
 {
 	set_modal();
-	text   = new gBox(8, 8, 284, 80, "");
-	clear  = new gClick(w()-88, text->y()+text->h()+8, 80, 20, "Clear");
-	cancel = new gClick(clear->x()-88, clear->y(), 80, 20, "Close");
+	text   = new geBox(8, 8, 284, 80, "");
+	clear  = new geButton(w()-88, text->y()+text->h()+8, 80, 20, "Clear");
+	cancel = new geButton(clear->x()-88, clear->y(), 80, 20, "Close");
 	end();
 
 	clear->callback(cb_clear, (void*)this);
