@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * gd_pluginChooser
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -35,22 +33,23 @@
 #include "../../core/channel.h"
 #include "../../core/conf.h"
 #include "../../core/pluginHost.h"
-#include "../elems/ge_pluginBrowser.h"
-#include "../elems/ge_mixed.h"
+#include "../elems/pluginBrowser.h"
+#include "../elems/basics/button.h"
+#include "../elems/basics/choice.h"
+#include "../elems/basics/box.h"
 #include "gd_pluginChooser.h"
 
 
-extern PluginHost G_PluginHost;
-extern Conf       G_Conf;
+using namespace giada::m;
 
 
-gdPluginChooser::gdPluginChooser(int X, int Y, int W, int H, int stackType, class Channel *ch)
-  : gWindow(X, Y, W, H, "Available plugins"), ch(ch), stackType(stackType)
+gdPluginChooser::gdPluginChooser(int X, int Y, int W, int H, int stackType, Channel *ch)
+  : gdWindow(X, Y, W, H, "Available plugins"), ch(ch), stackType(stackType)
 {
   /* top area */
   Fl_Group *group_top = new Fl_Group(8, 8, w()-16, 20);
-  sortMethod = new gChoice(group_top->x() + 45, group_top->y(), 100, 20, "Sort by");
-    gBox *b1 = new gBox(sortMethod->x()+sortMethod->w(), group_top->y(), 100, 20); 	// spacer window border <-> menu
+  sortMethod = new geChoice(group_top->x() + 45, group_top->y(), 100, 20, "Sort by");
+    geBox *b1 = new geBox(sortMethod->x()+sortMethod->w(), group_top->y(), 100, 20); 	// spacer window border <-> menu
   group_top->resizable(b1);
   group_top->end();
 
@@ -59,9 +58,9 @@ gdPluginChooser::gdPluginChooser(int X, int Y, int W, int H, int stackType, clas
 
   /* ok/cancel buttons */
   Fl_Group *group_btn = new Fl_Group(8, browser->y()+browser->h()+8, w()-16, h()-browser->h()-16);
-    gBox *b2 = new gBox(8, browser->y()+browser->h(), 100, 20); 	// spacer window border <-> buttons
-    addBtn = new gClick(w()-88, group_btn->y(), 80, 20, "Add");
-    cancelBtn = new gClick(addBtn->x()-88, group_btn->y(), 80, 20, "Cancel");
+    geBox *b2 = new geBox(8, browser->y()+browser->h(), 100, 20); 	// spacer window border <-> buttons
+    addBtn = new geButton(w()-88, group_btn->y(), 80, 20, "Add");
+    cancelBtn = new geButton(addBtn->x()-88, group_btn->y(), 80, 20, "Cancel");
   group_btn->resizable(b2);
   group_btn->end();
 
@@ -71,7 +70,7 @@ gdPluginChooser::gdPluginChooser(int X, int Y, int W, int H, int stackType, clas
   sortMethod->add("Category");
   sortMethod->add("Manufacturer");
   sortMethod->callback(cb_sort, (void*) this);
-  sortMethod->value(G_Conf.pluginSortMethod);
+  sortMethod->value(conf::pluginSortMethod);
 
   addBtn->callback(cb_add, (void*) this);
   addBtn->shortcut(FL_Enter);
@@ -88,11 +87,11 @@ gdPluginChooser::gdPluginChooser(int X, int Y, int W, int H, int stackType, clas
 
 gdPluginChooser::~gdPluginChooser()
 {
-  G_Conf.pluginChooserX = x();
-  G_Conf.pluginChooserY = y();
-  G_Conf.pluginChooserW = w();
-  G_Conf.pluginChooserH = h();
-  G_Conf.pluginSortMethod = sortMethod->value();
+  conf::pluginChooserX = x();
+  conf::pluginChooserY = y();
+  conf::pluginChooserW = w();
+  conf::pluginChooserH = h();
+  conf::pluginSortMethod = sortMethod->value();
 }
 
 
@@ -118,7 +117,7 @@ void gdPluginChooser::__cb_close()
 
 void gdPluginChooser::__cb_sort()
 {
-	G_PluginHost.sortPlugins(sortMethod->value());
+	pluginHost::sortPlugins(sortMethod->value());
   browser->refresh();
 }
 
