@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * gd_pluginList
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -29,30 +27,38 @@
 
 #ifdef WITH_VST
 
-#ifndef __GD_PLUGINLIST_H__
-#define __GD_PLUGINLIST_H__
+#ifndef GD_PLUGINLIST_H
+#define GD_PLUGINLIST_H
 
 #include <FL/Fl.H>
 #include <FL/Fl_Scroll.H>
-#include "../elems/ge_window.h"
+#include "window.h"
 
 
-class gdPluginList : public gWindow
+class Plugin;
+class Channel;
+class geButton;
+class gdPluginList;
+class geIdButton;
+class geChoice;
+
+
+class gdPluginList : public gdWindow
 {
 private:
 
- 	class gClick *addPlugin;
-	Fl_Scroll    *list;
+  geButton  *addPlugin;
+	Fl_Scroll *list;
 
 	static void cb_addPlugin  (Fl_Widget *v, void *p);
 	inline void __cb_addPlugin();
 
 public:
 
-	class Channel *ch;      // ch == NULL ? masterOut
-	int   stackType;
+	Channel *ch;      // ch == nullptr ? masterOut
+	int stackType;
 
-	gdPluginList(int stackType, class Channel *ch=NULL);
+	gdPluginList(int stackType, Channel *ch=nullptr);
 	~gdPluginList();
 
 	/* special callback, passed to browser. When closed (i.e. plugin
@@ -71,8 +77,8 @@ class gdPlugin : public Fl_Group
 {
 private:
 
-	class  gdPluginList *pParent;
-	class Plugin        *pPlugin;
+  gdPluginList *pParent;
+  Plugin       *pPlugin;
 
 	static void cb_removePlugin       (Fl_Widget *v, void *p);
 	static void cb_openPluginWindow   (Fl_Widget *v, void *p);
@@ -89,14 +95,14 @@ private:
 
 public:
 
-	class gButton *button;
-	class gChoice *program;
-	class gButton *bypass;
-	class gButton *shiftUp;
-	class gButton *shiftDown;
-	class gButton *remove;
+	geIdButton *button;
+	geChoice    *program;
+	geIdButton *bypass;
+	geIdButton *shiftUp;
+	geIdButton *shiftDown;
+	geIdButton *remove;
 
-	gdPlugin(gdPluginList *gdp, class Plugin *p, int x, int y, int w);
+	gdPlugin(gdPluginList *gdp, Plugin *p, int x, int y, int w);
 };
 
 #endif
