@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * gd_pluginWindow
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -28,22 +26,29 @@
 
 #ifdef WITH_VST
 
-#ifndef __GD_PLUGIN_WINDOW_H__
-#define __GD_PLUGIN_WINDOW_H__
+#ifndef GD_PLUGIN_WINDOW_H
+#define GD_PLUGIN_WINDOW_H
 
 
 #include <FL/Fl.H>
 #include <FL/Fl_Window.H>
-#include "../elems/ge_window.h"
+#include "window.h"
 
 
-class gdPluginWindow : public gWindow
+class Plugin;
+class geBox;
+class geSlider;
+
+
+class gdPluginWindow : public gdWindow
 {
 private:
-	class Plugin *pPlugin;
+
+  Plugin *pPlugin;
 
 public:
-	int id;
+
+  int id;
 
 	gdPluginWindow(Plugin *pPlugin);
 };
@@ -55,8 +60,9 @@ public:
 class Parameter : public Fl_Group
 {
 private:
-	int   paramIndex;
-	class Plugin *pPlugin;
+
+  int paramIndex;
+	Plugin *pPlugin;
 
 	static void cb_setValue(Fl_Widget *v, void *p);
 	inline void __cb_setValue();
@@ -64,11 +70,12 @@ private:
 	void updateValue();
 
 public:
-	class gBox    *label;
-	class gSlider *slider;
-	class gBox    *value;
 
-	Parameter(int paramIndex, class Plugin *p, int x, int y, int w);
+  geBox    *label;
+	geSlider *slider;
+	geBox    *value;
+
+	Parameter(int paramIndex, Plugin *p, int x, int y, int w);
 };
 
 
