@@ -209,9 +209,9 @@ void geMidiChannel::__cb_openMenu()
 
 	Fl_Menu_Button *b = new Fl_Menu_Button(0, 0, 100, 50);
 	b->box(G_CUSTOM_BORDER_BOX);
-	b->textsize(GUI_FONT_SIZE_BASE);
-	b->textcolor(COLOR_TEXT_0);
-	b->color(COLOR_BG_0);
+	b->textsize(G_GUI_FONT_SIZE_BASE);
+	b->textcolor(G_COLOR_LIGHT_2);
+	b->color(G_COLOR_GREY_2);
 
   const Fl_Menu_Item *m = rclick_menu->popup(Fl::event_x(), Fl::event_y(), 0, 0, b);
   if (m)
