@@ -1,10 +1,8 @@
-/* ---------------------------------------------------------------------
+/* -----------------------------------------------------------------------------
  *
  * Giada - Your Hardcore Loopmachine
  *
- * gg_waveTools
- *
- * ---------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
  * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
@@ -24,7 +22,7 @@
  * along with Giada - Your Hardcore Loopmachine. If not, see
  * <http://www.gnu.org/licenses/>.
  *
- * ------------------------------------------------------------------ */
+ * -------------------------------------------------------------------------- */
 
 
 #ifndef GE_WAVE_TOOLS_H
@@ -40,15 +38,31 @@ class geWaveform;
 
 class geWaveTools : public Fl_Scroll
 {
+private:
+
+	void openMenu();
+
 public:
 
+	SampleChannel *ch;
 	geWaveform *waveform;
 
 	geWaveTools(int X,int Y,int W, int H, SampleChannel *ch, const char *L=0);
 	void resize(int x, int y, int w, int h);
 	int  handle(int e);
 
+	/* updateWaveform
+	Updates the waveform by realloc-ing new data (i.e. when the waveform has
+	changed). */
+
 	void updateWaveform();
+
+	/* redrawWaveformAsync
+	Redraws the waveform, called by the video thread. This is meant to be called
+	repeatedly when you need to update the play head inside the waveform. The
+	method is smart enough to skip painting if the channel is stopped. */
+
+	void redrawWaveformAsync();
 };
 
 #endif
