@@ -2,9 +2,6 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * geWaveform
- * An element which represents a waveform.
- *
  * -----------------------------------------------------------------------------
  *
  * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
@@ -28,6 +25,7 @@
  * -------------------------------------------------------------------------- */
 
 
+#include <cassert>
 #include <cmath>
 #include <FL/fl_draw.H>
 #include <FL/Fl_Menu_Button.H>
@@ -38,27 +36,29 @@
 #include "../../../core/waveFx.h"
 #include "../../../core/sampleChannel.h"
 #include "../../../glue/channel.h"
+#include "../../../glue/sampleEditor.h"
 #include "../basics/boxtypes.h"
 #include "waveTools.h"
 #include "waveform.h"
 
 
 using namespace giada::m;
+using namespace giada::c;
 
 
-geWaveform::geWaveform(int x, int y, int w, int h, SampleChannel *ch, const char *l)
-: Fl_Widget(x, y, w, h, l),
-  chan(ch),
-  menuOpen(false),
-  chanStart(0),
+geWaveform::geWaveform(int x, int y, int w, int h, SampleChannel* ch, const char* l)
+: Fl_Widget   (x, y, w, h, l),
+  selection   {},
+  chan        (ch),
+  chanStart   (0),
   chanStartLit(false),
-  chanEnd(0),
-  chanEndLit(false),
-  ratio(0.0f),
-  selectionA(0),
-  selectionB(0),
-  selectionA_abs(0),
-  selectionB_abs(0)
+  chanEnd     (0),
+  chanEndLit  (false),
+  pushed      (false),
+  dragged     (false),
+  resizedA    (false),
+  resizedB    (false),
+  ratio       (0.0f)
 {
   data.sup  = nullptr;
   data.inf  = nullptr;
@@ -67,7 +67,7 @@ geWaveform::geWaveform(int x, int y, int w, int h, SampleChannel *ch, const char
   grid.snap  = conf::sampleEditorGridOn;
   grid.level = conf::sampleEditorGridVal;
 
-  stretchToWindow();
+  alloc(w);
 }
 
 
@@ -85,9 +85,9 @@ geWaveform::~geWaveform()
 
 void geWaveform::freeData()
 {
-  if (data.sup != nullptr) {
-    free(data.sup);
-    free(data.inf);
+  if (data.sup) {
+    delete[] data.sup;
+    delete[] data.inf;
     data.sup  = nullptr;
     data.inf  = nullptr;
     data.size = 0;
@@ -109,8 +109,11 @@ int geWaveform::alloc(int datasize)
   freeData();
 
   data.size = datasize;
-  data.sup  = (int*) malloc(data.size * sizeof(int));
-  data.inf  = (int*) malloc(data.size * sizeof(int));
+  data.sup  = new (std::nothrow) int[data.size];
+  data.inf  = new (std::nothrow) int[data.size];
+
+  if (!data.sup || !data.inf)
+    return 0;
 
   int offset = h() / 2;
   int zero   = y() + offset; // center, zero amplitude (-inf dB)
@@ -186,89 +189,81 @@ int geWaveform::alloc(int datasize)
 
 void geWaveform::recalcPoints()
 {
-  selectionA = relativePoint(selectionA_abs);
-  selectionB = relativePoint(selectionB_abs);
-  chanStart  = relativePoint(chan->begin / 2);
-
-  /* fix the rounding error when chanEnd is set on the very end of the
-   * sample */
-
-  if (chan->end == chan->wave->size)
-    chanEnd = data.size - 2; // 2 px border
-  else
-    chanEnd = relativePoint(chan->end / 2);
+  selection.aPixel = relativePoint(selection.aFrame);
+  selection.bPixel = relativePoint(selection.bFrame);
+  chanStart = relativePoint(chan->begin / 2);
+  chanEnd   = relativePoint(chan->end / 2);
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void geWaveform::draw()
+void geWaveform::drawSelection()
 {
-  /* blank canvas */
+  if (!isSelected()) 
+    return;
 
-  fl_rectf(x(), y(), w(), h(), COLOR_BG_0);
+  int a_x = selection.aPixel + x(); // - start;
+  int b_x = selection.bPixel + x(); //  - start;
 
-  /* draw selection (if any) */
+  if (a_x < 0)
+    a_x = 0;
+  if (b_x >= w() + BORDER)
+    b_x = w() + BORDER;
 
-  if (selectionA != selectionB) {
+  if (selection.aPixel < selection.bPixel)
+    fl_rectf(a_x, y(), b_x-a_x, h(), G_COLOR_GREY_4);
+  else
+    fl_rectf(b_x, y(), a_x-b_x, h(), G_COLOR_GREY_4);
+}
 
-    int a_x = selectionA + x() - BORDER; // - start;
-    int b_x = selectionB + x() - BORDER; //  - start;
 
-    if (a_x < 0)
-      a_x = 0;
-    if (b_x >= w()-1)
-      b_x = w()-1;
+/* -------------------------------------------------------------------------- */
 
-    if (selectionA < selectionB)
-      fl_rectf(a_x+BORDER, y(), b_x-a_x, h(), COLOR_BD_0);
-    else
-      fl_rectf(b_x+BORDER, y(), a_x-b_x, h(), COLOR_BD_0);
-  }
 
-  /* draw waveform from x1 (offset driven by the scrollbar) to x2
-   * (width of parent window). We don't draw the entire waveform,
-   * only the visibile part. */
+void geWaveform::drawWaveform(int from, int to)
+{
+  int zero = y() + (h() / 2); // zero amplitude (-inf dB)
 
-  int offset = h() / 2;
-  int zero   = y() + offset; // sample zero (-inf dB)
-
-  int wx1 = abs(x() - ((geWaveTools*)parent())->x());
-  int wx2 = wx1 + ((geWaveTools*)parent())->w();
-  if (x()+w() < ((geWaveTools*)parent())->w())
-    wx2 = x() + w() - BORDER;
-
-  fl_color(0, 0, 0);
-  for (int i=wx1; i<wx2; i++) {
+  fl_color(G_COLOR_BLACK);
+  for (int i=from; i<to; i++) {
     fl_line(i+x(), zero, i+x(), data.sup[i]);
     fl_line(i+x(), zero, i+x(), data.inf[i]);
+  }
+}
 
-    /* print grid */
 
+/* -------------------------------------------------------------------------- */
+
+
+void geWaveform::drawGrid(int from, int to)
+{
+  fl_color(G_COLOR_GREY_3);
+  fl_line_style(FL_DASH, 1, nullptr);
+  for (int i=from; i<to; i++) {
     for (unsigned k=0; k<grid.points.size(); k++) {
-      if (grid.points.at(k) == i) {
-        //gu_log("draw grid line at %d\n", i);
-        fl_color(fl_rgb_color(54, 54, 54));
-        fl_line_style(FL_DASH, 0, nullptr);
-        fl_line(i+x(), y(), i+x(), y()+h());
-        fl_color(0, 0, 0);
-        fl_line_style(FL_SOLID, 0, nullptr);
-        break;
-      }
+      if (grid.points.at(k) != i) 
+        continue;
+      fl_line(i+x(), y(), i+x(), y()+h());
+      break;
     }
   }
+  fl_line_style(FL_SOLID, 0, nullptr);
+}
 
-  /* border box */
 
-  fl_rect(x(), y(), w(), h(), COLOR_BD_0);
+/* -------------------------------------------------------------------------- */
 
+
+void geWaveform::drawStartEndPoints()
+{
   /* print chanStart */
 
-  int lineX = x()+chanStart+1;
+  int lineX = chanStart + x();
 
-  if (chanStartLit) fl_color(COLOR_BD_1);
-  else              fl_color(COLOR_BD_0);
+  if (chanStartLit) fl_color(G_COLOR_LIGHT_2);
+  else              fl_color(G_COLOR_LIGHT_1);
 
   /* vertical line */
 
@@ -283,9 +278,11 @@ void geWaveform::draw()
 
   /* print chanEnd */
 
-  lineX = x()+chanEnd;
-  if (chanEndLit) fl_color(COLOR_BD_1);
-  else            fl_color(COLOR_BD_0);
+  lineX = chanEnd + x() - 1;
+  if (chanEndLit) fl_color(G_COLOR_LIGHT_2);
+  else            fl_color(G_COLOR_LIGHT_1);
+
+  /* vertical line */
 
   fl_line(lineX, y()+1, lineX, y()+h()-2);
 
@@ -299,6 +296,48 @@ void geWaveform::draw()
 /* -------------------------------------------------------------------------- */
 
 
+void geWaveform::drawPlayHead()
+{
+  if (chan->status == STATUS_OFF)
+    return;
+  int p = ceilf(chan->tracker / ratio) + x();
+  fl_color(G_COLOR_LIGHT_2);
+  fl_line(p, y() + 1, p, y() + h() - 2);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void geWaveform::draw()
+{
+  assert(data.sup != nullptr);
+  assert(data.inf != nullptr);
+
+  fl_rectf(x(), y(), w(), h(), G_COLOR_GREY_2);  // blank canvas
+
+  /* Draw things from 'from' (offset driven by the scrollbar) to 'to' (width of 
+  parent window). We don't draw the entire waveform, only the visibile part. */
+
+  int from = abs(x() - parent()->x());
+  int to = from + parent()->w();
+  if (x() + w() < parent()->w())
+    to = x() + w() - BORDER;
+
+  drawSelection();
+  drawWaveform(from, to);
+  drawGrid(from, to);
+  drawPlayHead();
+
+  fl_rect(x(), y(), w(), h(), G_COLOR_GREY_4);   // border box
+  
+  drawStartEndPoints();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 int geWaveform::handle(int e)
 {
   int ret = 0;
@@ -311,47 +350,50 @@ int geWaveform::handle(int e)
       pushed = true;
 
       if (!mouseOnEnd() && !mouseOnStart()) {
-
-        /* right button? show the menu. Don't set selectionA,B,etc */
-
-        if (Fl::event_button3()) {
-          openEditMenu();
+        if (Fl::event_button3()) {  // let the parent (waveTools) handle this
+          ret = 0;
+          break;
         }
+        if (mouseOnSelectionA())
+          resizedA = true;
         else
-        if (mouseOnSelectionA() || mouseOnSelectionB()) {
-          resized = true;
-        }
+        if(mouseOnSelectionB())
+          resizedB = true;
         else {
           dragged = true;
-          selectionA = Fl::event_x() - x();
-
-          if (selectionA >= data.size) selectionA = data.size;
-
-          selectionB = selectionA;
-          selectionA_abs = absolutePoint(selectionA);
-          selectionB_abs = selectionA_abs;
+          selection.aPixel = Fl::event_x() - x();
+          selection.bPixel = selection.aPixel;
         }
       }
-
       ret = 1;
       break;
     }
 
     case FL_RELEASE: {
 
-      int realChanStart = chan->begin;
-      int realChanEnd   = chan->end;
+      /* If selection has been done (dragged or resized), make sure that point A 
+      is always lower than B. */
 
-      if (chanStartLit)
-        realChanStart = absolutePoint(chanStart)*2;
-      else
-      if (chanEndLit)
-        realChanEnd = absolutePoint(chanEnd)*2;
+      if (dragged || resizedA || resizedB)
+        fixSelection();
 
-      glue_setBeginEndChannel(chan, realChanStart, realChanEnd);
+      /* Handle begin/end markers interaction. */
 
-      pushed  = false;
-      dragged = false;
+      if (chanStartLit || chanEndLit) {
+        int realChanStart = chan->begin;
+        int realChanEnd   = chan->end;
+        if (chanStartLit)
+          realChanStart = absolutePoint(chanStart) * 2;
+        else
+        if (chanEndLit)
+          realChanEnd = absolutePoint(chanEnd) * 2;
+        sampleEditor::setBeginEndChannel(chan, realChanStart, realChanEnd);
+      }
+
+      pushed   = false;
+      dragged  = false;
+      resizedA = false;
+      resizedB = false;
 
       redraw();
       ret = 1;
@@ -397,10 +439,10 @@ int geWaveform::handle(int e)
         redraw();
       }
 
-      if (mouseOnSelectionA())
+      if (mouseOnSelectionA() && isSelected())
         fl_cursor(FL_CURSOR_WE, FL_WHITE, FL_BLACK);
       else
-      if (mouseOnSelectionB())
+      if (mouseOnSelectionB() && isSelected())
         fl_cursor(FL_CURSOR_WE, FL_WHITE, FL_BLACK);
       else
         fl_cursor(FL_CURSOR_DEFAULT, FL_WHITE, FL_BLACK);
@@ -424,7 +466,7 @@ int geWaveform::handle(int e)
           chanStart = 0;
         else
         if (chanStart >= chanEnd)
-          chanStart = chanEnd-2;
+          chanStart = chanEnd - 2;
 
         redraw();
       }
@@ -436,8 +478,8 @@ int geWaveform::handle(int e)
         if (grid.snap)
           chanEnd = applySnap(chanEnd);
 
-        if (chanEnd >= data.size - 2)
-          chanEnd = data.size - 2;
+        if (chanEnd > data.size)
+          chanEnd = data.size;
         else
         if (chanEnd <= chanStart)
           chanEnd = chanStart + 2;
@@ -445,42 +487,27 @@ int geWaveform::handle(int e)
         redraw();
       }
 
-      /* here the mouse is on the waveform, i.e. a selection */
+      /* Here the mouse is on the waveform, i.e. a new selection has started. */
 
       else
       if (dragged) {
-
-        selectionB = Fl::event_x() - x();
-
-        if (selectionB >= data.size)
-          selectionB = data.size;
-
-        if (selectionB <= 0)
-          selectionB = 0;
-
+        selection.bPixel = Fl::event_x() - x();
         if (grid.snap)
-          selectionB = applySnap(selectionB);
-
-        selectionB_abs = absolutePoint(selectionB);
+          selection.bPixel = applySnap(selection.bPixel);
         redraw();
       }
 
       /* here the mouse is on a selection boundary i.e. resize */
 
       else
-      if (resized) {
+      if (resizedA || resizedB) {
         int pos = Fl::event_x() - x();
-        if (mouseOnSelectionA()) {
-          selectionA     = grid.snap ? applySnap(pos) : pos;
-          selectionA_abs = absolutePoint(selectionA);
-        }
-        else
-        if (mouseOnSelectionB()) {
-          selectionB     = grid.snap ? applySnap(pos) : pos;
-          selectionB_abs = absolutePoint(selectionB);
-        }
+        if (grid.snap)
+          pos = applySnap(pos);
+        resizedA ? selection.aPixel = pos : selection.bPixel = pos;
         redraw();
       }
+
       mouseX = Fl::event_x();
       ret = 1;
       break;
@@ -492,12 +519,12 @@ int geWaveform::handle(int e)
 
 /* -------------------------------------------------------------------------- */
 
-/* pixel snap disances (10px) must be equal to those defined in
- * geWaveform::mouseOnSelectionA() and gWaverfrom::mouseOnSelectionB() */
-/* TODO - use constant for 10px */
 
 int geWaveform::applySnap(int pos)
 {
+  /* Pixel snap disances (SNAPPING) must be equal to those defined in 
+  mouseOnSelectionA() and mouseOnSelectionB(). */
+
   for (unsigned i=0; i<grid.points.size(); i++) {
     if (pos >= grid.points.at(i) - SNAPPING &&
         pos <= grid.points.at(i) + SNAPPING)
@@ -514,8 +541,8 @@ int geWaveform::applySnap(int pos)
 
 bool geWaveform::mouseOnStart()
 {
-  return mouseX-10 >  chanStart + x() - BORDER              &&
-         mouseX-10 <= chanStart + x() - BORDER + FLAG_WIDTH &&
+  return mouseX - (FLAG_WIDTH / 2) >  chanStart + x() - BORDER              &&
+         mouseX - (FLAG_WIDTH / 2) <= chanStart + x() - BORDER + FLAG_WIDTH &&
          mouseY    >  h() + y() - FLAG_HEIGHT;
 }
 
@@ -525,8 +552,8 @@ bool geWaveform::mouseOnStart()
 
 bool geWaveform::mouseOnEnd()
 {
-  return mouseX-10 >= chanEnd + x() - BORDER - FLAG_WIDTH &&
-         mouseX-10 <= chanEnd + x() - BORDER              &&
+  return mouseX - (FLAG_WIDTH / 2) >= chanEnd + x() - BORDER - FLAG_WIDTH &&
+         mouseX - (FLAG_WIDTH / 2) <= chanEnd + x() - BORDER              &&
          mouseY    <= y() + FLAG_HEIGHT + 1;
 }
 
@@ -538,17 +565,15 @@ bool geWaveform::mouseOnEnd()
 
 bool geWaveform::mouseOnSelectionA()
 {
-  if (selectionA == selectionB)
-    return false;
-  return mouseX >= selectionA-10+x() && mouseX <= selectionA+10+x();
+  return mouseX >= selection.aPixel - (FLAG_WIDTH / 2) + x() && 
+         mouseX <= selection.aPixel + (FLAG_WIDTH / 2) + x();
 }
 
 
 bool geWaveform::mouseOnSelectionB()
 {
-  if (selectionA == selectionB)
-    return false;
-  return mouseX >= selectionB-10+x() && mouseX <= selectionB+10+x();
+  return mouseX >= selection.bPixel - (FLAG_WIDTH / 2) + x() && 
+         mouseX <= selection.bPixel + (FLAG_WIDTH / 2) + x();
 }
 
 
@@ -579,146 +604,24 @@ int geWaveform::relativePoint(int p)
 /* -------------------------------------------------------------------------- */
 
 
-void geWaveform::openEditMenu()
+void geWaveform::fixSelection()
 {
-  if (selectionA == selectionB)
-    return;
-
-  menuOpen = true;
-
-  Fl_Menu_Item menu[] = {
-    {"Cut"},
-    {"Trim"},
-    {"Silence"},
-    {"Fade in"},
-    {"Fade out"},
-    {"Smooth edges"},
-    {"Set start/end here"},
-    {0}
-  };
-
-  if (chan->status == STATUS_PLAY) {
-    menu[0].deactivate();
-    menu[1].deactivate();
-  }
-
-  Fl_Menu_Button *b = new Fl_Menu_Button(0, 0, 100, 50);
-  b->box(G_CUSTOM_BORDER_BOX);
-  b->textsize(GUI_FONT_SIZE_BASE);
-  b->textcolor(COLOR_TEXT_0);
-  b->color(COLOR_BG_0);
-
-  const Fl_Menu_Item *m = menu->popup(Fl::event_x(), Fl::event_y(), 0, 0, b);
-  if (!m) {
-    menuOpen = false;
-    return;
-  }
-
-  /* straightSel() to ensure that point A is always lower than B */
-
-  straightSel();
-
-  if (strcmp(m->label(), "Silence") == 0) {
-    wfx_silence(chan->wave, absolutePoint(selectionA), absolutePoint(selectionB));
-
-    selectionA = 0;
-    selectionB = 0;
-
-    stretchToWindow();
-    redraw();
-    menuOpen = false;
-    return;
-  }
-
-  if (strcmp(m->label(), "Set start/end here") == 0) {
-
-    glue_setBeginEndChannel(chan, absolutePoint(selectionA) * 2, 
-      absolutePoint(selectionB) * 2); // stereo values
-
-    selectionA     = 0;
-    selectionB     = 0;
-    selectionA_abs = 0;
-    selectionB_abs = 0;
-
-    recalcPoints();
-    redraw();
-    menuOpen = false;
-    return;
-  }
-
-  if (strcmp(m->label(), "Cut") == 0) {
-    wfx_cut(chan->wave, absolutePoint(selectionA), absolutePoint(selectionB));
-
-    /* for convenience reset start/end points */
-
-    glue_setBeginEndChannel(chan, 0, chan->wave->size);
-
-    selectionA     = 0;
-    selectionB     = 0;
-    selectionA_abs = 0;
-    selectionB_abs = 0;
-
-    setZoom(0);
-
-    menuOpen = false;
-    return;
-  }
-
-  if (strcmp(m->label(), "Trim") == 0) {
-    wfx_trim(chan->wave, absolutePoint(selectionA), absolutePoint(selectionB));
-
-    glue_setBeginEndChannel(chan, 0, chan->wave->size);
-
-    selectionA     = 0;
-    selectionB     = 0;
-    selectionA_abs = 0;
-    selectionB_abs = 0;
-
-    stretchToWindow();
-    menuOpen = false;
-    redraw();
-    return;
-  }
-
-  if (!strcmp(m->label(), "Fade in") || !strcmp(m->label(), "Fade out")) {
-
-    int type = !strcmp(m->label(), "Fade in") ? 0 : 1;
-    wfx_fade(chan->wave, absolutePoint(selectionA), absolutePoint(selectionB), type);
-
-    selectionA = 0;
-    selectionB = 0;
-
-    stretchToWindow();
-    redraw();
-    menuOpen = false;
-    return;
-  }
-
-  if (!strcmp(m->label(), "Smooth edges")) {
-
-    wfx_smooth(chan->wave, absolutePoint(selectionA), absolutePoint(selectionB));
-
-    selectionA = 0;
-    selectionB = 0;
-
-    stretchToWindow();
-    redraw();
-    menuOpen = false;
-    return;
-  }
+  if (selection.aPixel > selection.bPixel) // inverted selection
+    std::swap(selection.aPixel, selection.bPixel);
+  selection.aFrame = absolutePoint(selection.aPixel);
+  selection.bFrame = absolutePoint(selection.bPixel);
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void geWaveform::straightSel()
+void geWaveform::clearSel()
 {
-  if (selectionA > selectionB) {
-    unsigned tmp = selectionB;
-    selectionB = selectionA;
-    selectionA = tmp;
-  }
+  selection.aPixel = 0;
+  selection.bPixel = 0;
+  selection.aFrame = 0;
+  selection.bFrame = 0;  
 }
 
 
@@ -727,48 +630,47 @@ void geWaveform::straightSel()
 
 void geWaveform::setZoom(int type)
 {
-  int newSize;
-  if (type == -1) newSize = data.size*2;  // zoom in
-  else            newSize = data.size/2;  // zoom out
+  int newSize = type == ZOOM_IN ? data.size * 2 : data.size / 2;
 
-  if (alloc(newSize)) {
-    size(data.size, h());
+  if (!alloc(newSize)) 
+    return;
 
-    /* zoom to pointer */
+  size(newSize, h());
 
-    int shift;
-    if (x() > 0)
-      shift = Fl::event_x() - x();
-    else
-    if (type == -1)
-      shift = Fl::event_x() + abs(x());
-    else
-      shift = (Fl::event_x() + abs(x())) / -2;
+  /* zoom to pointer */
 
-    if (x() - shift > BORDER)
-      shift = 0;
+  int shift;
+  if (x() > 0)
+    shift = Fl::event_x() - x();
+  else
+  if (type == ZOOM_IN)
+    shift = Fl::event_x() + abs(x());
+  else
+    shift = (Fl::event_x() + abs(x())) / -2;
 
-    position(x() - shift, y());
+  if (x() - shift > BORDER)
+    shift = 0;
+
+  position(x() - shift, y());
 
 
-    /* avoid overflow when zooming out with scrollbar like that:
-     * |----------[scrollbar]|
-     *
-     * offset vs smaller:
-     * |[wave------------| offset > 0  smaller = false
-     * |[wave----]       | offset < 0, smaller = true
-     * |-------------]   | offset < 0, smaller = false  */
+  /* avoid overflow when zooming out with scrollbar like that:
+   * |----------[scrollbar]|
+   *
+   * offset vs smaller:
+   * |[wave------------| offset > 0  smaller = false
+   * |[wave----]       | offset < 0, smaller = true
+   * |-------------]   | offset < 0, smaller = false  */
 
-    int  parentW = ((geWaveTools*)parent())->w();
-    int  thisW   = x() + w() - BORDER;           // visible width, not full width
+  int  parentW = parent()->w();
+  int  thisW   = x() + w() - BORDER;           // visible width, not full width
 
-    if (thisW < parentW)
-      position(x() + parentW - thisW, y());
-    if (smaller())
-      stretchToWindow();
+  if (thisW < parentW)
+    position(x() + parentW - thisW, y());
+  if (smaller())
+    stretchToWindow();
 
-    redraw();
-  }
+  redraw();
 }
 
 
@@ -777,7 +679,7 @@ void geWaveform::setZoom(int type)
 
 void geWaveform::stretchToWindow()
 {
-  int s = ((geWaveTools*)parent())->w();
+  int s = parent()->w();
   alloc(s);
   position(BORDER, y());
   size(s, h());
@@ -787,19 +689,21 @@ void geWaveform::stretchToWindow()
 /* -------------------------------------------------------------------------- */
 
 
-bool geWaveform::smaller()
+void geWaveform::refresh()
 {
-  return w() < ((geWaveTools*)parent())->w();
+  alloc(data.size);
+  redraw();
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-float geWaveform::displayRatio()
+bool geWaveform::smaller()
 {
-    return 1.0f / (data.size / (float) w());
-};
+  return w() < parent()->w();
+}
+
 
 /* -------------------------------------------------------------------------- */
 
@@ -811,3 +715,28 @@ void geWaveform::setGridLevel(int l)
   alloc(data.size);
   redraw();
 }
+
+
+/* -------------------------------------------------------------------------- */
+
+
+bool geWaveform::isSelected()
+{
+  return selection.aPixel != selection.bPixel;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+int geWaveform::getSelectionA()
+{
+  return selection.aFrame;
+}
+
+
+int geWaveform::getSelectionB()
+{
+  return selection.bFrame;
+}
+
