@@ -1,5 +1,5 @@
 #include "../src/core/wave.h"
-#include "catch.hpp"
+#include "catch/single_include/catch.hpp"
 
 
 using std::string;
